Ans="""

Step 2 − Add the following code to res/layout/activity_main.xml.

<?xml version="1.0" encoding="utf-8"?>
<RelativeLayout xmlns:android="http://schemas.android.com/apk/res/android"
   xmlns:tools="http://schemas.android.com/tools"
   android:layout_width="match_parent"
   android:layout_height="match_parent"
   tools:context=".MainActivity">
   <TextView
      android:id="@+id/textView"
      android:layout_width="wrap_content"
      android:layout_height="wrap_content"
      android:layout_centerInParent="true"
      android:text="Click button below to bring up snackBar" />
   <Button
      android:id="@+id/callbackButton"
      android:layout_width="wrap_content"
      android:layout_height="wrap_content"
      android:layout_centerInParent="true"
      android:layout_below="@id/textView"
      android:layout_marginTop="16sp"
      android:text="Tap To Display SnackBar"
      android:textStyle="bold"
      android:textSize="16sp"/>
</RelativeLayout>

Step 3 – Open build.gradle(Module app) add the following dependancy -

implementation 'com.android.support:design:28.0.0'

Step 4 − Add the following code to src/MainActivity.java

import android.graphics.Color;
import android.support.design.widget.Snackbar;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;
public class MainActivity extends AppCompatActivity {
   @Override
   protected void onCreate(Bundle savedInstanceState) {
      super.onCreate(savedInstanceState);
      setContentView(R.layout.activity_main);
      Button button = findViewById(R.id.callbackButton);
      button.setOnClickListener(new View.OnClickListener() {
         public void onClick(View v) {
            Snackbar snackBar = Snackbar .make(v, "An Error Occurred!", Snackbar.LENGTH_LONG) .setAction("RETRY", new View.OnClickListener() {
               @Override
               public void onClick(View view) {
               }
            });
            snackBar.setActionTextColor(Color.BLUE);
            View snackBarView = snackBar.getView();
            TextView textView = snackBarView.findViewById(android.support.design.R.id.snackbar_text);
            textView.setTextColor(Color.RED);
            snackBar.show();
         }
      });
   }
}

Step 4 - Add the following code to androidManifest.xml

<?xml version="1.0" encoding="utf-8"?>
<manifest xmlns:android="http://schemas.android.com/apk/res/android" package="app.com.sample">
   <application
      android:allowBackup="true"
      android:icon="@mipmap/ic_launcher"
      android:label="@string/app_name"
      android:roundIcon="@mipmap/ic_launcher_round"
      android:supportsRtl="true"
      android:theme="@style/AppTheme">
      <activity android:name=".MainActivity">
         <intent-filter>
            <action android:name="android.intent.action.MAIN" />
            <category android:name="android.intent.category.LAUNCHER" />
         </intent-filter>
      </activity>
   </application>
</manifest>
 
"""



Ans="""

    <?xml version="1.0" encoding="utf-8"?>  
    <android.support.constraint.ConstraintLayout xmlns:android="http://schemas.android.com/apk/res/android"  
        xmlns:app="http://schemas.android.com/apk/res-auto"  
        xmlns:tools="http://schemas.android.com/tools"  
        android:layout_width="match_parent"  
        android:layout_height="match_parent"  
        tools:context="example.javatpoint.com.alertdialog.MainActivity">  
      
        <Button  
            android:layout_width="wrap_content"  
            android:layout_height="wrap_content"  
            android:id="@+id/button"  
            android:text="Close app"  
            app:layout_constraintBottom_toBottomOf="parent"  
            app:layout_constraintLeft_toLeftOf="parent"  
            app:layout_constraintRight_toRightOf="parent"  
            app:layout_constraintTop_toTopOf="parent" />  
      
    </android.support.constraint.ConstraintLayout>  

strings.xml

Optionally, you can store the dialog message and title in the strings.xml file.
File: strings.xml

    <resources>  
        <string name="app_name">AlertDialog</string>  
        <string name="dialog_message">Welcome to Alert Dialog</string>  
        <string name="dialog_title">Javatpoint Alert Dialog</string>  
    </resources>  

Activity class

Let's write the code to create and show the AlertDialog.
File: MainActivity.java

    package example.javatpoint.com.alertdialog;  
      
    import android.content.DialogInterface;  
    import android.support.v7.app.AppCompatActivity;  
    import android.os.Bundle;  
    import android.view.View;  
    import android.widget.Button;  
    import android.app.AlertDialog;  
    import android.widget.Toast;  
      
    public class MainActivity extends AppCompatActivity {  
        Button closeButton;  
        AlertDialog.Builder builder;  
        @Override  
        protected void onCreate(Bundle savedInstanceState) {  
            super.onCreate(savedInstanceState);  
            setContentView(R.layout.activity_main);  
      
            closeButton = (Button) findViewById(R.id.button);  
            builder = new AlertDialog.Builder(this);  
            closeButton.setOnClickListener(new View.OnClickListener() {  
                @Override  
                public void onClick(View v) {  
      
                    //Uncomment the below code to Set the message and title from the strings.xml file  
                    builder.setMessage(R.string.dialog_message) .setTitle(R.string.dialog_title);  
      
                    //Setting message manually and performing action on button click  
                    builder.setMessage("Do you want to close this application ?")  
                            .setCancelable(false)  
                            .setPositiveButton("Yes", new DialogInterface.OnClickListener() {  
                                public void onClick(DialogInterface dialog, int id) {  
                                    finish();  
                                    Toast.makeText(getApplicationContext(),"you choose yes action for alertbox",  
                                    Toast.LENGTH_SHORT).show();  
                                }  
                            })  
                            .setNegativeButton("No", new DialogInterface.OnClickListener() {  
                                public void onClick(DialogInterface dialog, int id) {  
                                    //  Action for 'NO' Button  
                                    dialog.cancel();  
                                    Toast.makeText(getApplicationContext(),"you choose no action for alertbox",  
                                    Toast.LENGTH_SHORT).show();  
                                }  
                            });  
                    //Creating dialog box  
                    AlertDialog alert = builder.create();  
                    //Setting the title manually  
                    alert.setTitle("AlertDialogExample");  
                    alert.show();  
                }  
            });  
        }  
    }  
}
    
"""



Ans="""

<asp:AdRotator  runat = "server" AdvertisementFile = "adfile.xml"  Target =  "_blank" />

<Advertisements>
   <Ad>
      <ImageUrl>rose1.jpg</ImageUrl>
      <NavigateUrl>http://www.1800flowers.com</NavigateUrl>
      <AlternateText>
         Order flowers, roses, gifts and more
      </AlternateText>
      <Impressions>20</Impressions>
      <Keyword>flowers</Keyword>
   </Ad>

   <Ad>
      <ImageUrl>rose2.jpg</ImageUrl>
      <NavigateUrl>http://www.babybouquets.com.au</NavigateUrl>
      <AlternateText>Order roses and flowers</AlternateText>
      <Impressions>20</Impressions>
      <Keyword>gifts</Keyword>
   </Ad>

   <Ad>
      <ImageUrl>rose3.jpg</ImageUrl>
      <NavigateUrl>http://www.flowers2moscow.com</NavigateUrl>
      <AlternateText>Send flowers to Russia</AlternateText>
      <Impressions>20</Impressions>
      <Keyword>russia</Keyword>
   </Ad>

   <Ad>
      <ImageUrl>rose4.jpg</ImageUrl>
      <NavigateUrl>http://www.edibleblooms.com</NavigateUrl>
      <AlternateText>Edible Blooms</AlternateText>
      <Impressions>20</Impressions>
      <Keyword>gifts</Keyword>
   </Ad>
</Advertisements>

<form id="form1" runat="server">
   <div>
      <asp:AdRotator ID="AdRotator1" runat="server" AdvertisementFile  ="~/ads.xml" onadcreated="AdRotator1_AdCreated" />
   </div>
</form>


"""



Ans="""

0xxx 	Class A 	general purpose unicast addresses with standard 8 bit prefix
10xx 	Class B 	general purpose unicast addresses with standard 16 bit prefix
110x 	Class C 	general purpose unicast addresses with standard 24 bit prefix
1110 	Class D 	IP Multicast Addresses - 28 bit prefix, non- aggregatable
1111 	Class E 	reserved for experimental use 

"""



Ans="""
'''

import java.awt.BorderLayout;
import java.awt.EventQueue;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.border.EmptyBorder;
import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.JLabel;
import java.awt.Color;
import java.awt.Font;
import javax.swing.JButton;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import javax.swing.LayoutStyle.ComponentPlacement;
import java.sql.*;
public class AdminSuccess extends JFrame {
	static AdminSuccess frame;
	private JPanel contentPane;

	/**
	 * Launch the application.
	 */
	public static void main(String[] args) {
		EventQueue.invokeLater(new Runnable() {
			public void run() {
				try {
					frame = new AdminSuccess();
					frame.setVisible(true);
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		});
	}

	/**
	 * Create the frame.
	 */
	public AdminSuccess() {
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		setBounds(100, 100, 450, 371);
		contentPane = new JPanel();
		contentPane.setBorder(new EmptyBorder(5, 5, 5, 5));
		setContentPane(contentPane);
		
		JLabel lblAdminSection = new JLabel("Admin Section");
		lblAdminSection.setFont(new Font("Tahoma", Font.PLAIN, 22));
		lblAdminSection.setForeground(Color.GRAY);
		
		JButton btnNewButton = new JButton("Add Librarian");
		btnNewButton.setFont(new Font("Tahoma", Font.PLAIN, 15));
		btnNewButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
			LibrarianForm.main(new String[]{});
			frame.dispose();
			}
		});
		
		JButton btnViewLibrarian = new JButton("View Librarian");
		btnViewLibrarian.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent arg0) {
			ViewLibrarian.main(new String[]{});
			}
		});
		btnViewLibrarian.setFont(new Font("Tahoma", Font.PLAIN, 15));
		
		JButton btnDeleteLibrarian = new JButton("Delete Librarian");
		btnDeleteLibrarian.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
			DeleteLibrarian.main(new String[]{});
			frame.dispose();
			}
		});
		btnDeleteLibrarian.setFont(new Font("Tahoma", Font.PLAIN, 15));
		
		JButton btnLogout = new JButton("Logout");
		btnLogout.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent arg0) {
				Library.main(new String[]{});
				frame.dispose();
			}
		});
		btnLogout.setFont(new Font("Tahoma", Font.PLAIN, 15));
		GroupLayout gl_contentPane = new GroupLayout(contentPane);
		gl_contentPane.setHorizontalGroup(
			gl_contentPane.createParallelGroup(Alignment.TRAILING)
				.addGroup(gl_contentPane.createSequentialGroup()
					.addContainerGap(150, Short.MAX_VALUE)
					.addComponent(lblAdminSection, GroupLayout.PREFERRED_SIZE, 151, GroupLayout.PREFERRED_SIZE)
					.addGap(123))
				.addGroup(Alignment.LEADING, gl_contentPane.createSequentialGroup()
					.addGap(134)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.LEADING)
						.addComponent(btnLogout, GroupLayout.PREFERRED_SIZE, 181, GroupLayout.PREFERRED_SIZE)
						.addComponent(btnDeleteLibrarian, GroupLayout.PREFERRED_SIZE, 181, GroupLayout.PREFERRED_SIZE)
						.addComponent(btnViewLibrarian, GroupLayout.PREFERRED_SIZE, 181, GroupLayout.PREFERRED_SIZE)
						.addComponent(btnNewButton, GroupLayout.PREFERRED_SIZE, 181, GroupLayout.PREFERRED_SIZE))
					.addContainerGap(109, Short.MAX_VALUE))
		);
		gl_contentPane.setVerticalGroup(
			gl_contentPane.createParallelGroup(Alignment.LEADING)
				.addGroup(gl_contentPane.createSequentialGroup()
					.addComponent(lblAdminSection, GroupLayout.PREFERRED_SIZE, 40, GroupLayout.PREFERRED_SIZE)
					.addGap(11)
					.addComponent(btnNewButton, GroupLayout.PREFERRED_SIZE, 49, GroupLayout.PREFERRED_SIZE)
					.addGap(18)
					.addComponent(btnViewLibrarian, GroupLayout.PREFERRED_SIZE, 49, GroupLayout.PREFERRED_SIZE)
					.addGap(18)
					.addComponent(btnDeleteLibrarian, GroupLayout.PREFERRED_SIZE, 49, GroupLayout.PREFERRED_SIZE)
					.addGap(18)
					.addComponent(btnLogout, GroupLayout.PREFERRED_SIZE, 49, GroupLayout.PREFERRED_SIZE)
					.addContainerGap(21, Short.MAX_VALUE))
		);
		contentPane.setLayout(gl_contentPane);
	}
}

'''
"""



Ans="""

import numpy as np
m = np.array([[1,2],[3,4]])
print("Original matrix:")
print(m)
test =  np.linalg.det(m)
if test>=0:
    result =  np.linalg.inv(m)
    print("Inverse of the said matrix:")
    print(result)
else:
    print("Inverse of the said matrix not possible!")

"""



Ans="""

Define the type of the following destination addresses:
a. 4A:30:10:21:10:1A
b. 47:20:1B:2E:08:EE
c. FF:FF:FF:FF:FF:FF
Solution
To find the type of the address, we need to look at the second hexadecimal digit from the left. If it
is even, the address is unicast. If it is odd, the address is multicast. If all digits are Fs, the address
is broadcast. Therefore, we have the following:
a. This is a unicast address because A in binary is 1010 (even). 
b. This is a multicast address because 7 in binary is 0111 (odd).
c. This is a broadcast address because all digits are Fs in hexadecimal

"""



Ans="""


Step 1: Creating the Required XML File named 'Countries.xml'.

    <?xml version="1.0" encoding="utf-8" ?>  
    <Countries>  
        <Country>  
            <CountryID>1</CountryID>  
            <CountryName>India</CountryName>  
        </Country>  
        <Country>  
            <CountryID>2</CountryID>  
            <CountryName>USA</CountryName>  
        </Country>  
        <Country>  
            <CountryID>3</CountryID>  
            <CountryName>China</CountryName>  
        </Country>  
        <Country>  
            <CountryID>4</CountryID>  
            <CountryName>Australia</CountryName>  
        </Country>  
        <Country>  
            <CountryID>5</CountryID>  
            <CountryName>United Kingdom</CountryName>  
        </Country>  
        <Country>  
            <CountryID>6</CountryID>  
            <CountryName>Brazil</CountryName>  
        </Country>  
    </Countries>    

Step 2: Drag and Drop a Dropdownlist Control from ASP.NET Controls Toolbox and Press F7 Key to Add the Below code to the Code Behind File.

    using System;    
    using System.Data;    
    using System.Web.UI.WebControls;    
    namespace DDLPopulateWithXML    
    {    
        public partial class WebForm1 : System.Web.UI.Page    
        {    
            protected void Page_Load(object sender, EventArgs e)    
            {    
                if (!IsPostBack) //Used to Check that Whether the page loads first time or Second Time    
                {    
                    DataSet ds = new DataSet(); //Created a Dataset to Store data    
                    ds.ReadXml(Server.MapPath("Countries.xml")); // Using ReadXml Method of the Dataset Class and Server.MapPath is used to  
    Get the Correct path of the XML File    
                    DropDownList1.DataSource = ds; //Setting the Datasource of DDL to Dataset    
                    DropDownList1.DataTextField = "CountryName"; //This is the name of the tag of XML file through which we want to Show the Values    
                    DropDownList1.DataValueField = "CountryID"; //This is the Primary key on which the Data is fetched    
                    DropDownList1.DataBind(); //Data is Binded with the dropdownlist    
                    ListItem LI = new ListItem("---Select---", "-1"); //Used to Show Some Custom Text in the list of DDL    
                    DropDownList1.Items.Insert(0,LI); //Used to Insert the Above Value at the 0 Index Location of the DDL, so that It appears  
    on Top    
                }    
            }    
        }    
    } 
        

"""



Ans="""
'''

Steps to create Struts Application –
Download and extract Struts2 binary distribution files. It is freely available online. Here it is recommend downloading the “Full Distribution” zip file containing all dependency jar files.
1.Create JSPs
2.Create action pages according to JSPs
3.Connect the JSPs ad action pages using configuration files (such as web.xml and struts.xml).
Web Application1
-Web pages
-Meta-INF Context.xml
-Web-INF Web.xml
-Source packages
-Default packages
-Libraries
-All struts libraries 
-Configuration files 
-Manifest.MF
-Context.xml
-Web-fragment.xml
-Web.xml

1.And create “index.jsp” by selecting new Java server page document.

<%@page contentType="text/html" pageEncoding="UTF-8"%>
<%taglib prefix = "s" uri="/struts-tags"%>
<html>
<body>
<s:form method ="post" action ="hello_action">
<s:labelvalue ="Enter your name in text box and click the button" name="label1"/>
<s:textfield name ="name"/>
<s:submit value ="CLICK" name="submit"/>
</s:form>
</body>
</html>
2.This will generate certain output.
3.Create another jsp page named as “result.jsp” inside jsp folder.

//result.jsp
<%@page contentType="text/html" pageEncoding="UTF-8"%>
<%taglib prefix = "s" uri="/struts-tags"%>
<html>
<body>
<h1>Hello<s:property value="name"/></h1>
</body>
</html>
4.The folder here is known as package. Create a folder named action_jsp inside source packages.
5.Create action class “hello_action” inside “action_jsp” package.
6.So the hello_action java file will be as follwos:

import com.opensymphony.xwork2.ActionSupport;
//everything in here must be kept public to have package level access.

public class hello_ation extends ActionSupport
{
private String name;
//getter and setter methods for the form element value
 public String getName()
{
return name;
}
public void setName(String name)
{
this.name = name;
}
//method that returns success or failure on action
public String execute()
{
return "success";
}
}
 
7.Struts.xml can be written as:

<!DOCTYPE struts PUBLIC
"-//Apache Software Foundation//DTD Sturts Configuration 2.0//En"
"http://struts.apache.org/dtds/struts-2.0.dtd">

<struts>
<package name ="default" extends ="struts-default">
<action name ="hello_action" class ="action_jsp.hello_action" method ="execute">
<result name ="success">result.jsp</result>
<result name ="failure">index.jsp</result>
</action>
</package>
</struts>
 
8.In web.xml, change the welcome file to our index.jsp

<?xml version ="1.0" encoding ="UTF-8"?>


<web-app version ="3.1" xmlns = "http://xmlns.jcp.org/xml/ns/javaee" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
xsi:schemaLocation ="http://xmlns.jcp.org./xml/ns//javaee http://xmlns.jcp.org./xml/ns/javaee/web-app_3_1.xsd">
<filter>
<filter-name>struts2</filter-name>
<filter-class>org.apace.struts2.dispatcher.FilterDispatcer</filter-class>
</filter>
<filter-mapping>
<filter-name>struts<//filter-name>
<url-pattern>/*</url-pattern>
</filter-mapping>
<session-config>
<session-timeout>
30
</sesson-timeout>
</session-config>
<welcome-file-list>
<welcome-file>jsp/index.jsp</welcome-file>
</welcome-file-list>
</web-app>

9.Run the application. And see the welcome message.


'''
"""



Ans='''"""

import matplotlib.pyplot as plt
import numpy as np
x=[2,4,6,8,10,12]
y=[2,2,2,2,2,2]
plt.plot(x,y,'b')
plt.xlabel('input')
plt.ylabel('steps')
plt.title('Constant complexity')
plt.show()

"""
'''



Ans="""

Following is the content of the modified main activity file src/com.example.demo/MainActivity.java. This file can include each of the fundamental lifecycle methods.

package com.example.demo;

import android.os.Bundle;
import android.app.Activity;

public class MainActivity extends Activity {
   @Override
   protected void onCreate(Bundle savedInstanceState) {
      super.onCreate(savedInstanceState);
      setContentView(R.layout.activity_main);
   }
   
}

Following will be the content of res/layout/activity_main.xml file −

<RelativeLayout xmlns:android="http://schemas.android.com/apk/res/android"
   android:layout_width="fill_parent"
   android:layout_height="fill_parent"
   android:paddingLeft="16dp"
   android:paddingRight="16dp" >
   
   <EditText
      android:id="@+id/name"
      android:layout_width="fill_parent"
      android:layout_height="wrap_content"
      android:hint="@string/reminder" />
      
   <LinearLayout
      android:orientation="vertical"
      android:layout_width="fill_parent"
      android:layout_height="fill_parent"
      android:layout_alignParentStart="true"
      android:layout_below="@+id/name">
      
      <Button
         android:layout_width="wrap_content"
         android:layout_height="wrap_content"
         android:text="New Button"
         android:id="@+id/button" />
      
      <Button
         android:layout_width="wrap_content"
         android:layout_height="wrap_content"
         android:text="New Button"
         android:id="@+id/button2" />
      
   </LinearLayout>

</RelativeLayout>

Following will be the content of res/values/strings.xml to define two new constants −

<?xml version="1.0" encoding="utf-8"?>
<resources>
   <string name="action_settings">Settings</string>
   <string name="reminder">Enter your name</string>
</resources>

"""



Ans="""

using System;

namespace MyNamespace
{
    public class SampleClass
    {
        public static void myMethod()
        {
            Console.WriteLine("Creating my namespace");
        }
    }
}
 
namespace MyProgram
{
    public class MyClass
    {
        public static void Main()
        {
            MyNamespace.SampleClass.myMethod();
        }
    }
}

"""



Ans="""


using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.Data.SqlClient;
namespace IUDS_SimpleCS
{
public partial class Form1 : Form
{
public Form1()
{
InitializeComponent();
}
SqlConnection con = new SqlConnection(@"Data Source=.\sqlexpress;Initial Catalog=Employee;Integrated Security=True");
 
 
private void btnAdd_Click(object sender, EventArgs e)
{
try
{
if (txtEmpName.Text == "" || txtEmpDegn.Text == "" || txtSalary.Text == "")
{
MessageBox.Show("All Fields Are Compulsory");
}
else
{
SqlCommand cmdinsert = new SqlCommand("Insert into EmployeeDetails values( ' " + txtEmpName.Text + " ','" + txtEmpDegn.Text + "','" + txtSalary.Text + "' )", con);
con.Open();
cmdinsert.CommandType = CommandType.Text;
cmdinsert.ExecuteNonQuery();
MessageBox.Show("Data Inserted");
}
}
catch (Exception ex)
{
MessageBox.Show(ex.Message);
}
finally
{
if (con.State == ConnectionState.Open)
{
con.Close();
}
}
}
 
private void btnUpdate_Click(object sender, EventArgs e)
{
try
{
if (txtempid.Text == "")
{
MessageBox.Show("Enter Employee Id To Update");
}
else
{
SqlCommand cmdupdate = new SqlCommand("Update EmployeeDetails SET EmpName='" + txtEmpName.Text + "',EmpDesgn='" + txtEmpDegn.Text + "' ,EmpSalary='" + txtSalary.Text + "' where EmpId=" + txtempid.Text + "", con);
con.Open();
cmdupdate.CommandType = CommandType.Text;
cmdupdate.ExecuteNonQuery();
MessageBox.Show("Data Updated");
}
}
catch (Exception ex)
{
MessageBox.Show(ex.Message);
}
finally
{
if (con.State == ConnectionState.Open)
{
con.Close();
}
}
}
 
private void btnDel_Click(object sender, EventArgs e)
{
try
{
if (txtempid.Text == "")
{
MessageBox.Show("Enter Employee Id To Delete");
}
else
{
SqlCommand cmddel = new SqlCommand("Delete EmployeeDetails where EmpId=" + txtempid.Text + "", con);
con.Open();
cmddel.CommandType = CommandType.Text;
cmddel.ExecuteNonQuery();
MessageBox.Show("Data Deleted");
}
}
catch (Exception ex)
{
MessageBox.Show(ex.Message);
}
finally
{
if (con.State == ConnectionState.Open)
{
con.Close();
}
}
}
 
 
 
private void btnSelect_Click(object sender, EventArgs e)
{
try
{
if (txtempid.Text == "")
{
MessageBox.Show("Enter Employee Id To Search");
}
else
{
SqlCommand cmd = new SqlCommand("Select * From EmployeeDetails where EmpId=" + txtempid.Text + "", con);
con.Open();
 
cmd.CommandType = CommandType.Text;
SqlDataReader dr = cmd.ExecuteReader();
if (dr.Read())
{
txtEmpName.Text = dr[1].ToString();
txtEmpDegn.Text = dr[2].ToString();
txtSalary.Text = dr[3].ToString();
}
dr.Close();
}
}
catch (Exception ex)
{
MessageBox.Show(ex.Message);
}
finally
{
if (con.State == ConnectionState.Open)
{
con.Close();
}
}
}
 
private void btnReset_Click(object sender, EventArgs e)
{
foreach (Control T in Controls)
{
if (T is TextBox)
{
T.Text = "";
}
}
}
}
}

        

"""



Ans="""
'''

import java.awt.BorderLayout;
import java.awt.EventQueue;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.border.EmptyBorder;
import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.JLabel;
import java.awt.Color;
import java.awt.Font;
import javax.swing.JButton;
import javax.swing.LayoutStyle.ComponentPlacement;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

public class Library extends JFrame {
	static Library frame;
	private JPanel contentPane;

	/**
	 * Launch the application.
	 */
	public static void main(String[] args) {
		EventQueue.invokeLater(new Runnable() {
			public void run() {
				try {
					frame= new Library();
					frame.setVisible(true);
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		});
	}

	/**
	 * Create the frame.
	 */
	public Library() {
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		setBounds(100, 100, 450, 300);
		contentPane = new JPanel();
		contentPane.setBorder(new EmptyBorder(5, 5, 5, 5));
		setContentPane(contentPane);
		
		JLabel lblLibraryManagement = new JLabel("Library Management - JavaTpoint");
		lblLibraryManagement.setFont(new Font("Tahoma", Font.PLAIN, 18));
		lblLibraryManagement.setForeground(Color.GRAY);
		
		JButton btnAdminLogin = new JButton("Admin Login");
		btnAdminLogin.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
			AdminLogin.main(new String[]{});
			frame.dispose();
			}
		});
		btnAdminLogin.setFont(new Font("Tahoma", Font.PLAIN, 15));
		
		JButton btnLibrarianLogin = new JButton("Librarian Login");
		btnLibrarianLogin.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent arg0) {
				LibrarianLogin.main(new String[]{});
			}
		});
		btnLibrarianLogin.setFont(new Font("Tahoma", Font.PLAIN, 15));
		GroupLayout gl_contentPane = new GroupLayout(contentPane);
		gl_contentPane.setHorizontalGroup(
			gl_contentPane.createParallelGroup(Alignment.LEADING)
				.addGroup(gl_contentPane.createSequentialGroup()
					.addGroup(gl_contentPane.createParallelGroup(Alignment.LEADING)
						.addGroup(gl_contentPane.createSequentialGroup()
							.addGap(64)
							.addComponent(lblLibraryManagement))
						.addGroup(gl_contentPane.createSequentialGroup()
							.addGap(140)
							.addGroup(gl_contentPane.createParallelGroup(Alignment.TRAILING, false)
								.addComponent(btnLibrarianLogin, Alignment.LEADING, GroupLayout.DEFAULT_SIZE, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
								.addComponent(btnAdminLogin, Alignment.LEADING, GroupLayout.DEFAULT_SIZE, 135, Short.MAX_VALUE))))
					.addContainerGap(95, Short.MAX_VALUE))
		);
		gl_contentPane.setVerticalGroup(
			gl_contentPane.createParallelGroup(Alignment.LEADING)
				.addGroup(gl_contentPane.createSequentialGroup()
					.addContainerGap()
					.addComponent(lblLibraryManagement)
					.addGap(32)
					.addComponent(btnAdminLogin, GroupLayout.PREFERRED_SIZE, 52, GroupLayout.PREFERRED_SIZE)
					.addPreferredGap(ComponentPlacement.UNRELATED)
					.addComponent(btnLibrarianLogin, GroupLayout.PREFERRED_SIZE, 53, GroupLayout.PREFERRED_SIZE)
					.addContainerGap(70, Short.MAX_VALUE))
		);
		contentPane.setLayout(gl_contentPane);
	}
}
'''
"""



Ans="""

Step 2 − Add the following code to res/layout/activity_main.xml.

<? xml version= "1.0" encoding= "utf-8" ?>
<android.support.v4.widget.DrawerLayout
   xmlns: android = "http://schemas.android.com/apk/res/android"
   xmlns: app = "http://schemas.android.com/apk/res-auto"
   xmlns: tools = "http://schemas.android.com/tools"
   android :id= "@+id/drawer_layout"
   android :layout_width= "match_parent"
   android :layout_height= "match_parent"
   android :fitsSystemWindows= "true"
   tools :openDrawer= "start" >
   <include
      layout= "@layout/app_bar_main"
      android :layout_width= "match_parent"
      android :layout_height= "match_parent" />
   <android.support.design.widget.NavigationView
      android :id= "@+id/nav_view"
      android :layout_width= "wrap_content"
      android :layout_height= "match_parent"
      android :layout_gravity= "start"
      android :fitsSystemWindows= "true"
      app :headerLayout= "@layout/nav_header_main"
      app :menu= "@menu/activity_main_drawer" />
</android.support.v4.widget.DrawerLayout>

Step 3 − Add the following code to res/layout/nav_header_main.xml.

<? xml version= "1.0" encoding= "utf-8" ?>
<LinearLayout xmlns: android = "http://schemas.android.com/apk/res/android"
   xmlns: app = "http://schemas.android.com/apk/res-auto"
   android :layout_width= "match_parent"
   android :layout_height= "@dimen/nav_header_height"
   android :background= "@drawable/side_nav_bar"
   android :gravity= "bottom"
   android :orientation= "vertical"
   android :paddingLeft= "@dimen/activity_horizontal_margin"
   android :paddingTop= "@dimen/activity_vertical_margin"
   android :paddingRight= "@dimen/activity_horizontal_margin"
   android :paddingBottom= "@dimen/activity_vertical_margin"
   android :theme= "@style/ThemeOverlay.AppCompat.Dark" >
   <ImageView
      android :id= "@+id/imageView"
      android :layout_width= "wrap_content"
      android :layout_height= "wrap_content"
      android :contentDescription= "@string/nav_header_desc"
      android :paddingTop= "@dimen/nav_header_vertical_spacing"
      app :srcCompat= "@mipmap/ic_launcher_round" />
   <TextView
      android :layout_width= "match_parent"
      android :layout_height= "wrap_content"
      android :paddingTop= "@dimen/nav_header_vertical_spacing"
      android :text= "@string/nav_header_title"
      android :textAppearance= "@style/TextAppearance.AppCompat.Body1" />
   <TextView
      android :id= "@+id/textView"
      android :layout_width= "wrap_content"
      android :layout_height= "wrap_content"
      android :text= "@string/nav_header_subtitle" />
</LinearLayout>

Step 4 − Add the following code to res/layout/app_bar_main.xml.

<? xml version= "1.0" encoding= "utf-8" ?>
<android.support.design.widget.CoordinatorLayout
   xmlns: android = "http://schemas.android.com/apk/res/android"
   xmlns: app = "http://schemas.android.com/apk/res-auto"
   xmlns: tools = "http://schemas.android.com/tools"
   android :layout_width= "match_parent"
   android :layout_height= "match_parent"
   tools :context= ".MainActivity" >
   <android.support.design.widget.AppBarLayout
      android :layout_width= "match_parent"
      android :layout_height= "wrap_content"
      android :theme= "@style/AppTheme.AppBarOverlay" >
   <android.support.v7.widget.Toolbar
      android :id= "@+id/toolbar"
      android :layout_width= "match_parent"
      android :layout_height= "?attr/actionBarSize"
      android :background= "?attr/colorPrimary"
      app :popupTheme= "@style/AppTheme.PopupOverlay" />
   </android.support.design.widget.AppBarLayout>
   <include layout= "@layout/content_main" />
   <android.support.design.widget.FloatingActionButton
      android :id= "@+id/fab"
      android :layout_width= "wrap_content"
      android :layout_height= "wrap_content"
      android :layout_gravity= "bottom|end"
      android :layout_margin= "@dimen/fab_margin"
      app :srcCompat= "@android:drawable/ic_dialog_email" />
</android.support.design.widget.CoordinatorLayout>

Step 5 − Add the following code to res/layout/content_main.xml.

<? xml version= "1.0" encoding= "utf-8" ?>
<android.support.constraint.ConstraintLayout
   xmlns: android = "http://schemas.android.com/apk/res/android"
   xmlns: app = "http://schemas.android.com/apk/res-auto"
   xmlns: tools = "http://schemas.android.com/tools"
   android :layout_width= "match_parent"
   android :layout_height= "match_parent"
   app :layout_behavior= "@string/appbar_scrolling_view_behavior"
   tools :context= ".MainActivity"
   tools :showIn= "@layout/app_bar_main" >
</android.support.constraint.ConstraintLayout>

Step 6 − Add the following code to res/menu/activity_main_drawer.xml.

<? xml version= "1.0" encoding= "utf-8" ?>
<menu xmlns: android = "http://schemas.android.com/apk/res/android"
   xmlns: tools = "http://schemas.android.com/tools"
   tools :showIn= "navigation_view" >
   <group android :checkableBehavior= "single" >
      <item
         android :id= "@+id/nav_camera"
         android :icon= "@drawable/ic_menu_camera"
         android :title= "Import" />
      <item
         android :id= "@+id/nav_gallery"
         android :icon= "@drawable/ic_menu_gallery"
         android :title= "Gallery" />
      <item
         android :id= "@+id/nav_slideshow"
         android :icon= "@drawable/ic_menu_slideshow"
         android :title= "Slideshow" />
      <item
         android :id= "@+id/nav_manage"
         android :icon= "@drawable/ic_menu_manage"
         android :title= "Tools" />
   </group>
   <item android :title= "Communicate" >
      <menu>
         <item
            android :id= "@+id/nav_share"
            android :icon= "@drawable/ic_menu_share"
            android :title= "Share" />
         <item
            android :id= "@+id/nav_send"
            android :icon= "@drawable/ic_menu_send"
            android :title= "Send" />
      </menu>
   </item>
</menu>

Step 7 − Add the following code to src/MainActivity.java

package app.tutorialspoint.com.sample ;
import android.os.Bundle ;
import android.support.annotation. NonNull ;
import android.support.design.widget.FloatingActionButton ;
import android.support.design.widget.Snackbar ;
import android.view.View ;
import android.support.design.widget.NavigationView ;
import android.support.v4.view.GravityCompat ;
import android.support.v4.widget.DrawerLayout ;
import android.support.v7.app.ActionBarDrawerToggle ;
import android.support.v7.app.AppCompatActivity ;
import android.support.v7.widget.Toolbar ;
import android.view.Menu ;
import android.view.MenuItem ;
public class MainActivity extends AppCompatActivity
implements NavigationView.OnNavigationItemSelectedListener {
   @Override
   protected void onCreate (Bundle savedInstanceState) {
      super .onCreate(savedInstanceState) ;
      setContentView(R.layout. activity_main ) ;
      Toolbar toolbar = findViewById(R.id. toolbar ) ;
      setSupportActionBar(toolbar) ;
      FloatingActionButton fab = findViewById(R.id. fab ) ;
      fab.setOnClickListener( new View.OnClickListener() {
         @Override
         public void onClick (View view) {
            Snackbar. make (view , "Replace with your own action" ,
            Snackbar. LENGTH_LONG )
            .setAction( "Action" , null ).show() ;
         }
      }) ;
      DrawerLayout drawer = findViewById(R.id. drawer_layout ) ;
      ActionBarDrawerToggle toggle = new ActionBarDrawerToggle(
      this, drawer , toolbar , R.string. navigation_drawer_open ,
      R.string. navigation_drawer_close ) ;
      drawer.addDrawerListener(toggle) ;
      toggle.syncState() ;
      NavigationView navigationView = findViewById(R.id. nav_view ) ;
      navigationView.setNavigationItemSelectedListener( this ) ;
   }
   @Override
   public void onBackPressed () {
      DrawerLayout drawer = findViewById(R.id. drawer_layout ) ;
      if (drawer.isDrawerOpen(GravityCompat. START )) {
         drawer.closeDrawer(GravityCompat. START ) ;
      } else {
         super .onBackPressed() ;
      }
   }
   @Override
   public boolean onCreateOptionsMenu (Menu menu) {
      // Inflate the menu; this adds items to the action bar if it is present.
      getMenuInflater().inflate(R.menu. main , menu) ;
      return true;
   }
   @Override
   public boolean onOptionsItemSelected (MenuItem item) {
      int id = item.getItemId() ;
      if (id == R.id. action_settings ) {
         return true;
      }
      return super .onOptionsItemSelected(item) ;
   }
   @SuppressWarnings ( "StatementWithEmptyBody" )
   @Override
   public boolean onNavigationItemSelected ( @NonNull MenuItem item) {
      // Handle navigation view item clicks here.
      int id = item.getItemId() ;
      if (id == R.id. nav_camera ) {
         // Handle the camera action
      } else if (id == R.id. nav_gallery ) {
      } else if (id == R.id. nav_slideshow ) {
         } else if (id == R.id. nav_manage ) {
         } else if (id == R.id. nav_share ) {
         } else if (id == R.id. nav_send ) {
      }
      DrawerLayout drawer = findViewById(R.id. drawer_layout ) ;
      drawer.closeDrawer(GravityCompat. START ) ;
      return true;
   }
}

Step 8 − Add the following code to androidManifest.xml

<? xml version= "1.0" encoding= "utf-8" ?>
<manifest xmlns: android = "http://schemas.android.com/apk/res/android"
   package= "app.tutorialspoint.com.sample" >
   <application
      android :allowBackup= "true"
      android :icon= "@mipmap/ic_launcher"
      android :label= "@string/app_name"
      android :roundIcon= "@mipmap/ic_launcher_round"
      android :supportsRtl= "true"
      android :theme= "@style/AppTheme" >
      <activity
         android :name= ".MainActivity"
         android :theme= "@style/AppTheme.NoActionBar" >
         <intent-filter>
            <action android :name= "android.intent.action.MAIN" />
            <category android :name= "android.intent.category.LAUNCHER" />
         </intent-filter>
      </activity>
   </application>
</manifest>
 
"""



Ans="""
'''

import java.awt.BorderLayout;
import java.awt.EventQueue;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.border.EmptyBorder;
import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.JLabel;
import javax.swing.JOptionPane;

import java.awt.Font;
import java.awt.Color;
import javax.swing.JTextField;
import javax.swing.JButton;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import javax.swing.JPasswordField;

public class LibrarianLogin extends JFrame {
	static LibrarianLogin frame;
	private JPanel contentPane;
	private JTextField textField;
	private JPasswordField passwordField;

	/**
	 * Launch the application.
	 */
	public static void main(String[] args) {
		EventQueue.invokeLater(new Runnable() {
			public void run() {
				try {
					frame = new LibrarianLogin();
					frame.setVisible(true);
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		});
	}

	/**
	 * Create the frame.
	 */
	public LibrarianLogin() {
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		setBounds(100, 100, 450, 300);
		contentPane = new JPanel();
		contentPane.setBorder(new EmptyBorder(5, 5, 5, 5));
		setContentPane(contentPane);
		
		JLabel lblAdminLoginForm = new JLabel("Librarian Login Form");
		lblAdminLoginForm.setForeground(Color.GRAY);
		lblAdminLoginForm.setFont(new Font("Tahoma", Font.PLAIN, 18));
		
		JLabel lblEnterName = new JLabel("Enter Name:");
		
		JLabel lblEnterPassword = new JLabel("Enter Password:");
		
		textField = new JTextField();
		textField.setColumns(10);
		
		JButton btnLogin = new JButton("Login");
		btnLogin.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
			String name=textField.getText();
			String password=String.valueOf(passwordField.getPassword());
			//System.out.println(name+" "+password);
			if(LibrarianDao.validate(name, password)){
				LibrarianSuccess.main(new String[]{});
				frame.dispose();
			}else{
				JOptionPane.showMessageDialog(LibrarianLogin.this, "Sorry, Username or Password Error","Login Error!", JOptionPane.ERROR_MESSAGE);
				textField.setText("");
				passwordField.setText("");
			}
			}
		});
		
		passwordField = new JPasswordField();
		GroupLayout gl_contentPane = new GroupLayout(contentPane);
		gl_contentPane.setHorizontalGroup(
			gl_contentPane.createParallelGroup(Alignment.TRAILING)
				.addGroup(gl_contentPane.createSequentialGroup()
					.addGroup(gl_contentPane.createParallelGroup(Alignment.LEADING)
						.addGroup(gl_contentPane.createSequentialGroup()
							.addGap(124)
							.addComponent(lblAdminLoginForm))
						.addGroup(gl_contentPane.createSequentialGroup()
							.addGap(19)
							.addGroup(gl_contentPane.createParallelGroup(Alignment.LEADING)
								.addComponent(lblEnterName)
								.addComponent(lblEnterPassword))
							.addGap(47)
							.addGroup(gl_contentPane.createParallelGroup(Alignment.LEADING, false)
								.addComponent(passwordField)
								.addComponent(textField, GroupLayout.DEFAULT_SIZE, 172, Short.MAX_VALUE))))
					.addContainerGap(107, Short.MAX_VALUE))
				.addGroup(gl_contentPane.createSequentialGroup()
					.addContainerGap(187, Short.MAX_VALUE)
					.addComponent(btnLogin, GroupLayout.PREFERRED_SIZE, 86, GroupLayout.PREFERRED_SIZE)
					.addGap(151))
		);
		gl_contentPane.setVerticalGroup(
			gl_contentPane.createParallelGroup(Alignment.LEADING)
				.addGroup(gl_contentPane.createSequentialGroup()
					.addComponent(lblAdminLoginForm)
					.addGap(26)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.BASELINE)
						.addComponent(lblEnterName)
						.addComponent(textField, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
					.addGap(28)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.BASELINE)
						.addComponent(lblEnterPassword)
						.addComponent(passwordField, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
					.addGap(18)
					.addComponent(btnLogin, GroupLayout.PREFERRED_SIZE, 37, GroupLayout.PREFERRED_SIZE)
					.addContainerGap(80, Short.MAX_VALUE))
		);
		contentPane.setLayout(gl_contentPane);
	}
}
'''
"""



Ans="""

int loginAttempts = 0;

    //Simple iteration upto three times
    for (int i = 0; i < 3; i++)
    {
        Console.WriteLine("Enter username");
        string username = Console.ReadLine();
        Console.WriteLine("Enter password");
        string password = Console.ReadLine();

        if (username != "valid" || password != "valid")
            loginAttempts++;
        else
            break;
    }

    //Display the result
    if (loginAttempts > 2)
        Console.WriteLine("Login failure");
    else
        Console.WriteLine("Login successful");

    Console.ReadKey();
        

"""



Ans="""

static void Main(string[] args)  
{  
    string _inputstr, _reversestr = string.Empty;  
    Console.Write("Enter a string : ");  
    _inputstr = Console.ReadLine();  
    if (_inputstr != null)  
    {  
        for (int i = _inputstr.Length - 1; i >= 0; i--)  
        {  
            _reversestr += _inputstr[i].ToString();  
        }  
        if (_reversestr == _inputstr)  
        {  
            Console.WriteLine("String is Palindrome Input = {0} and Output= {1}", _inputstr, _reversestr);  
        }  
        else  
        {  
            Console.WriteLine("String is not Palindrome Input = {0} and Output= {1}", _inputstr, _reversestr);  
        }  
    }  
    Console.ReadLine();  
} 

"""



Ans="""

ile can include each of the fundamental lifecycle methods.

package com.example.demo;

import android.os.Bundle;
import android.app.Activity;

public class MainActivity extends Activity {
   @Override
   protected void onCreate(Bundle savedInstanceState) {
      super.onCreate(savedInstanceState);
      setContentView(R.layout.activity_main);
   }
}

Following will be the content of res/layout/activity_main.xml file −

<?xml version="1.0" encoding="utf-8"?>
<LinearLayout xmlns:android="http://schemas.android.com/apk/res/android"
   android:layout_width="fill_parent"
   android:layout_height="fill_parent"
   android:orientation="vertical" >
   
   <Button android:id="@+id/btnStartService"
      android:layout_width="270dp"
      android:layout_height="wrap_content"
      android:text="start_service"/>
      
   <Button android:id="@+id/btnPauseService"
      android:layout_width="270dp"
      android:layout_height="wrap_content"
      android:text="pause_service"/>
      
   <Button android:id="@+id/btnStopService"
      android:layout_width="270dp"
      android:layout_height="wrap_content"
      android:text="stop_service"/>
      
</LinearLayout>

Following will be the content of res/values/strings.xml to define two new constants −

<?xml version="1.0" encoding="utf-8"?>
<resources>
   <string name="app_name">HelloWorld</string>
   <string name="action_settings">Settings</string>
</resources>

"""



Ans="""

    <?xml version="1.0" encoding="utf-8"?>  
    <RelativeLayout xmlns:android="http://schemas.android.com/apk/res/android"  
        xmlns:app="http://schemas.android.com/apk/res-auto"  
        xmlns:tools="http://schemas.android.com/tools"  
        android:layout_width="match_parent"  
        android:layout_height="match_parent"  
        tools:context="example.javatpoint.com.datepicker.MainActivity">  
      
        <TextView  
            android:id="@+id/textView1"  
            android:layout_width="wrap_content"  
            android:layout_height="wrap_content"  
            android:layout_above="@+id/button1"  
            android:layout_alignParentLeft="true"  
            android:layout_alignParentStart="true"  
            android:layout_marginBottom="102dp"  
            android:layout_marginLeft="30dp"  
            android:layout_marginStart="30dp"  
            android:text="" />  
      
        <Button  
            android:id="@+id/button1"  
            android:layout_width="wrap_content"  
            android:layout_height="wrap_content"  
            android:layout_alignParentBottom="true"  
            android:layout_centerHorizontal="true"  
            android:layout_marginBottom="20dp"  
            android:text="Change Date" />  
      
        <DatePicker  
            android:id="@+id/datePicker"  
            android:layout_width="wrap_content"  
            android:layout_height="wrap_content"  
            android:layout_above="@+id/textView1"  
            android:layout_centerHorizontal="true"  
            android:layout_marginBottom="36dp" />  
      
    </RelativeLayout>  

Activity class

File: MainActivity.java

    package example.javatpoint.com.datepicker;  
      
    import android.support.v7.app.AppCompatActivity;  
    import android.os.Bundle;  
    import android.view.View;  
    import android.widget.Button;  
    import android.widget.DatePicker;  
    import android.widget.TextView;  
      
    public class MainActivity extends AppCompatActivity {  
        DatePicker picker;  
        Button displayDate;  
        TextView textview1;  
        @Override  
        protected void onCreate(Bundle savedInstanceState) {  
            super.onCreate(savedInstanceState);  
            setContentView(R.layout.activity_main);  
      
            textview1=(TextView)findViewById(R.id.textView1);  
            picker=(DatePicker)findViewById(R.id.datePicker);  
            displayDate=(Button)findViewById(R.id.button1);  
      
            textview1.setText("Current Date: "+getCurrentDate());  
      
            displayDate.setOnClickListener(new View.OnClickListener(){  
                @Override  
                public void onClick(View view) {  
      
                    textview1.setText("Change Date: "+getCurrentDate());  
                }  
      
            });  
      
        }  
        public String getCurrentDate(){  
            StringBuilder builder=new StringBuilder();;  
            builder.append((picker.getMonth() + 1)+"/");//month is 0 based  
            builder.append(picker.getDayOfMonth()+"/");  
            builder.append(picker.getYear());  
            return builder.toString();  
        }  
    }  
    
"""



Ans="""

import matplotlib.pyplot as plt
S={3+3j,4+3j,2+1j,2.5+1j,3+1j,3.25+1j}
print('Select operation')
print('1: Addition of two 2 complex number ')
print('2: Plot points from set of complex number')
print('3:Translation')
print('4:Scaling')
print('5:Rotation')
print('6:Exit')
while True:
    ch=int(input('Enter choice for operation'))
    if ch==1:
        c1=complex(input('Enter complex no c1'))
        c2=complex(input('Enter complex no c2'))
        print('Addition of two 2 complex number(c1+c2)is',c1+c2)
    elif ch==2:
        S1={x for x in S}
    elif ch==3:
        c1=complex(input('Enter Translation in complex no format'))
        S1={x+c1 for x in S}
    elif ch==4:
        scale=float(input('Enter scale pointlike(0.5)for 1/2'))
        S1={x*scale for x in S}
    elif ch==5:
        angle=int(input('Enter angle of rotation 90/180/270'))
        if angle==90:
            S1={x*1j for x in S}
        elif angle==180:
            S1={x*-1 for x in S}
        elif angle==270:
            S1={x*1j-1 for x in S}
        else:
            print('Invalid angle Enter only 90/180/270 degree')
    else:
        break
X=[x.real for x in S1]
Y=[x.imag for x in S1]
plt.plot(X,Y,'ro')
plt.axis([-6,6,-6,6])
plt.show()

"""



Ans="""





3. Fiber-optic Cable

New transmission medium used by telephone companies in place of long-distance trunk lines.
This cable also used by private companies in implementing local data communication networks.
Optical fiber consists of a glass cladding with slightly lower refractive index.
Fiber optic cable is used as the high speed backbone.
Fiber Optic Advantages Greater capacity (bandwidth of up to 2 Gbps).
Smaller size and lighter weight.
Lower attenuation.
immunity to environmental interference.
highly secure due to tap difficulty and lack of signal radiation.
Fiber Optic Disadvantages expensive over short distance
requires highly skilled installers adding additional nodes is difficult
Applications
The fiber optic cable is often found in backbone networks because its bandwidth is cost effective.
Used in TV companies.
LAN such as 100 Base-FX Network 

"""



Ans="""

13.4 GIGABIT ETHERNET
The need for an even higher data rate resulted in the design of the Gigabit Ethernet
Protocol (1000 Mbps). The IEEE committee calls it the Standard 802.3z. The goals of
the Gigabit Ethernet were to upgrade the data rate to 1 Gbps, but keep the address
length, the frame format, and the maximum and minimum frame length the same. The
goals of the Gigabit Ethernet design can be summarized as follows:
1. Upgrade the data rate to 1 Gbps.
2. Make it compatible with Standard or Fast Ethernet.
3. Use the same 48-bit address.
4. Use the same frame format.
5. Keep the same minimum and maximum frame lengths.
6. Support autonegotiation as defined in Fast Ethernet.

"""



Ans="""
'''
Null Space:

The null space of any matrix A consists of all the vectors B such that AB = 0
and B is not zero. It can also be thought as the solution obtained from AB = 0
where A is known matrix of size m x n and B is matrix to be found of size n x k.
The size of the null space of the matrix provides us with the number
of linear relations among attributes.

'''
from sympy import Matrix 
  
# List A  
A = [[1, 2, 0], [2, 4, 0], [3, 6, 1]] 
  
# Matrix A 
A = Matrix(A) 
  
# Null Space of A 
NullSpace = A.nullspace()   # Here NullSpace is a list 
  
NullSpace = Matrix(NullSpace)   # Here NullSpace is a Matrix 
print("Null Space : ", NullSpace) 
  
# checking whether NullSpace satisfies the 
# given condition or not as A * NullSpace = 0 
# if NullSpace is null space of A 
print(A * NullSpace) 
"""



Ans='''"""

DESCRIPTION:
The binary search tree is implemented using a node class and methods to print and traverse through it are also defined.
a class method no_of_nodes() is implemented to return and print the no. of nodes in the BST . this function actually counts the length of the list of nodes formed using the treepaths function .

PROGRAM:
class node:
    """a node class with a constructor setting the node and left and
    right child to None by default"""
    def __init__(self, data):
        self.data = data
        self.right = self.left = None

    def insert(self, x):
        """insert hte new data in a node based on the value comparision with root
        if the root value is greater than new node then it is stored in left subtree
        and if the root is less than new value , the data is stored in right subtree"""
        if self.data:
            if self.data > x:
                if self.left is None:
                    self.left = node(x)
                else:
                    self.left.insert(x)
            elif self.data < x:
                if self.right is None:
                    self.right = node(x)
                else:
                    self.right.insert(x)
        else:
            self.data = x

    def print_tree(self):
        """printing of tree in inorder fashion"""
        if self.left:
            self.left.print_tree()
        print(self.data)
        if self.right:
            self.right.print_tree()

    def tree_values(self):
        """getting a list of all the nodes in the BST by calling the treevalues
        function ."""
        my_list = []
        return self.treevalues(my_list)

    def treevalues(self, my_list):
        if self.left:
            self.left.treevalues(my_list)
        my_list.append(self.data)
        if self.right:
            self.right.treevalues(my_list)

        return my_list

    def no_of_nodes(self):
        """calls the tree_values() function and gets its length"""
        print(len(self.tree_values()))

def main():
    root = node(5)
    root.insert(2)
    root.insert(6)
    root.insert(3)
    print("the tree is-->")
    root.print_tree()
    print("\n the no. of nodes-->")
    root.no_of_nodes()

if __name__=='__main__':
    main()


"""
'''



Ans='''"""

def selection_sort(integers):
    """Search through a list of Integers using the selection sorting method.
    Search elements 0 through n - 1 and select smallest, swap with element at
    index 0, iteratively search through elements n - 1 and swap with smallest.
    """
    integers_clone = list(integers)

    for index in range(len(integers_clone) - 1, 0, -1):
        max_position = 0
        for location in range(1, index + 1):
            if integers_clone[location] > integers_clone[max_position]:
                max_position = location

        temp = integers_clone[index]
        integers_clone[index] = integers_clone[max_position]
        integers_clone[max_position] = temp

    return integers_clone

"""
'''



Ans="""

from math import *
pf=[]
n=int(input('enter no'))
x=n
while n%2==0:
pf.append(2)
n=n/2
i=3
while i<=sqrt(n):
while n%i==0:
pf.append(i)
n=n/i
i=i+2
if n>2:
pf.append(n)
print('prime factors of',x,'are',pf)
pf1=set(pf)
nf=1
for f in pf1:
cnt=0
for f1 in pf:
if f==f1:
cnt+=1
nf*=cnt+1
print('no of fators of',x,'=',nf)
print('no of positive integral solutions=',nf/2)

"""



Ans="""

using System;  
class Program {  
    static void Main() {  
        //Declaration  
        bool isPrime = true;  
        int i, j;  
        //Calculate and display the Prime number  
        Console.WriteLine("Prime Numbers are : ");  
        for (i = 2; i <= 100; i++) {  
            for (j = 2; j <= 100; j++) {  
                if (i != j && i % j == 0) {  
                    isPrime = false;  
                    break;  
                }  
            }  
            if (isPrime) {  
                Console.Write("\t" + i);  
            }  
            isPrime = true;  
        }  
        Console.ReadKey();  
    }  
} 

"""



Ans="""

<%@ OutputCache Duration="10" VaryByParam="none" %>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" 

  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head runat="server">
    <title>OutPutCacheWithDuration</title>
</head>
<body>
    <form id="form1" runat="server">
    <div>
        <asp:Label ID="lblResult" runat="server"></asp:Label>
        <br />
        <br />
        <asp:Button ID="btnPostBack" runat="server" Text="Post Back"  />
        <p>
            The page will be cached 10s, and then you can 
                   click Button to update datetime.
        </p>
    </div>
    </form>
</body>
</html>

"""



Ans="""

public partial class PageLiftCycle: System.Web.UI.Page {  
    protected void Page_PreInit(object sender, EventArgs e) {  
        //Work and It will assign the values to label.  
        lblName.Text = lblName.Text + "<br/>" + "PreInit";  
    }  
    protected void Page_Init(object sender, EventArgs e) {  
        //Work and It will assign the values to label.  
        lblName.Text = lblName.Text + "<br/>" + "Init";  
    }  
    protected void Page_InitComplete(object sender, EventArgs e) {  
        //Work and It will assign the values to label.  
        lblName.Text = lblName.Text + "<br/>" + "InitComplete";  
    }  
    protected override void OnPreLoad(EventArgs e) {  
        //Work and It will assign the values to label.  
        //If the page is post back, then label contrl values will be loaded from view state.  
        //E.g: If you string str = lblName.Text, then str will contain viewstate values.  
        lblName.Text = lblName.Text + "<br/>" + "PreLoad";  
    }  
    protected void Page_Load(object sender, EventArgs e) {  
        //Work and It will assign the values to label.  
        lblName.Text = lblName.Text + "<br/>" + "Load";  
    }  
    protected void btnSubmit_Click(object sender, EventArgs e) {  
        //Work and It will assign the values to label.  
        lblName.Text = lblName.Text + "<br/>" + "btnSubmit_Click";  
    }  
    protected void Page_LoadComplete(object sender, EventArgs e) {  
        //Work and It will assign the values to label.  
        lblName.Text = lblName.Text + "<br/>" + "LoadComplete";  
    }  
    protected override void OnPreRender(EventArgs e) {  
        //Work and It will assign the values to label.  
        lblName.Text = lblName.Text + "<br/>" + "PreRender";  
    }  
    protected override void OnSaveStateComplete(EventArgs e) {  
        //Work and It will assign the values to label.  
        //But "SaveStateComplete" values will not be available during post back. i.e. View state.  
        lblName.Text = lblName.Text + "<br/>" + "SaveStateComplete";  
    }  
    protected void Page_UnLoad(object sender, EventArgs e) {  
        //Work and it will not effect label contrl, view stae and post back data.  
        lblName.Text = lblName.Text + "<br/>" + "UnLoad";  
    }  
}
        

"""



Ans="""

AndroidStudioProjects\SqliteApp\app\src\main\res\layout\activity_main.xml
<RelativeLayout xmlns:android="http://schemas.android.com/apk/res/android"
    xmlns:tools="http://schemas.android.com/tools" android:layout_width="match_parent"
    android:layout_height="match_parent" android:paddingLeft="@dimen/activity_horizontal_margin"
    android:paddingRight="@dimen/activity_horizontal_margin"
    android:paddingTop="@dimen/activity_vertical_margin"
    android:paddingBottom="@dimen/activity_vertical_margin" tools:context=".MainActivity">

    <TextView
        android:layout_width="wrap_content"
        android:layout_height="wrap_content"
        android:textAppearance="?android:attr/textAppearanceLarge"
        android:text="Name"
        android:id="@+id/textView"
        android:layout_alignParentTop="true"
        android:layout_alignParentLeft="true"
        android:layout_alignParentStart="true" />

    <TextView
        android:layout_width="wrap_content"
        android:layout_height="wrap_content"
        android:textAppearance="?android:attr/textAppearanceLarge"
        android:text="Surname"
        android:id="@+id/textView2"
        android:layout_below="@+id/editText_name"
        android:layout_alignParentLeft="true"
        android:layout_alignParentStart="true" />

    <TextView
        android:layout_width="wrap_content"
        android:layout_height="wrap_content"
        android:textAppearance="?android:attr/textAppearanceLarge"
        android:text="Marks"
        android:id="@+id/textView3"
        android:layout_below="@+id/editText_surname"
        android:layout_alignParentLeft="true"
        android:layout_alignParentStart="true" />

    <EditText
        android:layout_width="match_parent"
        android:layout_height="wrap_content"
        android:id="@+id/editText_name"
        android:layout_alignTop="@+id/textView"
        android:layout_toRightOf="@+id/textView"
        android:layout_toEndOf="@+id/textView" />

    <EditText
        android:layout_width="match_parent"
        android:layout_height="wrap_content"
        android:id="@+id/editText_surname"
        android:layout_alignTop="@+id/textView2"
        android:layout_toRightOf="@+id/textView2"
        android:layout_toEndOf="@+id/textView2" />

    <EditText
        android:layout_width="match_parent"
        android:layout_height="wrap_content"
        android:id="@+id/editText_Marks"
        android:layout_below="@+id/editText_surname"
        android:layout_toRightOf="@+id/textView3"
        android:layout_toEndOf="@+id/textView3" />

    <Button
        android:layout_width="wrap_content"
        android:layout_height="wrap_content"
        android:text="Add Data"
        android:id="@+id/button_add"
        android:layout_below="@+id/editText_Marks"
        android:layout_alignParentLeft="true"
        android:layout_alignParentStart="true"
        android:layout_marginTop="76dp" />

    <Button
        android:layout_width="wrap_content"
        android:layout_height="wrap_content"
        android:text="View All"
        android:id="@+id/button_viewAll"
        android:layout_above="@+id/button_update"
        android:layout_centerHorizontal="true" />

    <Button
        android:layout_width="wrap_content"
        android:layout_height="wrap_content"
        android:text="Update"
        android:id="@+id/button_update"
        android:layout_below="@+id/button_add"
        android:layout_alignParentLeft="true"
        android:layout_alignParentStart="true" />


    <Button
        android:layout_width="wrap_content"
        android:layout_height="wrap_content"
        android:text="Delete"
        android:id="@+id/button_delete"
        android:layout_centerVertical="true"
        android:layout_below="@+id/button_viewAll"
        android:layout_alignLeft="@+id/button_viewAll"
        android:layout_alignStart="@+id/button_viewAll" />

    <TextView
        android:layout_width="wrap_content"
        android:layout_height="wrap_content"
        android:textAppearance="?android:attr/textAppearanceLarge"
        android:text="id"
        android:id="@+id/textView_id"
        android:layout_below="@+id/editText_Marks"
        android:layout_alignParentLeft="true"
        android:layout_alignParentStart="true" />

    <EditText
        android:layout_width="match_parent"
        android:layout_height="wrap_content"
        android:id="@+id/editText_id"
        android:layout_alignTop="@+id/textView_id"
        android:layout_toRightOf="@+id/textView3"
        android:layout_toEndOf="@+id/textView3" />

</RelativeLayout>
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
	
<RelativeLayout xmlns:android="http://schemas.android.com/apk/res/android"
    xmlns:tools="http://schemas.android.com/tools" android:layout_width="match_parent"
    android:layout_height="match_parent" android:paddingLeft="@dimen/activity_horizontal_margin"
    android:paddingRight="@dimen/activity_horizontal_margin"
    android:paddingTop="@dimen/activity_vertical_margin"
    android:paddingBottom="@dimen/activity_vertical_margin" tools:context=".MainActivity">
 
    <TextView
        android:layout_width="wrap_content"
        android:layout_height="wrap_content"
        android:textAppearance="?android:attr/textAppearanceLarge"
        android:text="Name"
        android:id="@+id/textView"
        android:layout_alignParentTop="true"
        android:layout_alignParentLeft="true"
        android:layout_alignParentStart="true" />
 
    <TextView
        android:layout_width="wrap_content"
        android:layout_height="wrap_content"
        android:textAppearance="?android:attr/textAppearanceLarge"
        android:text="Surname"
        android:id="@+id/textView2"
        android:layout_below="@+id/editText_name"
        android:layout_alignParentLeft="true"
        android:layout_alignParentStart="true" />
 
    <TextView
        android:layout_width="wrap_content"
        android:layout_height="wrap_content"
        android:textAppearance="?android:attr/textAppearanceLarge"
        android:text="Marks"
        android:id="@+id/textView3"
        android:layout_below="@+id/editText_surname"
        android:layout_alignParentLeft="true"
        android:layout_alignParentStart="true" />
 
    <EditText
        android:layout_width="match_parent"
        android:layout_height="wrap_content"
        android:id="@+id/editText_name"
        android:layout_alignTop="@+id/textView"
        android:layout_toRightOf="@+id/textView"
        android:layout_toEndOf="@+id/textView" />
 
    <EditText
        android:layout_width="match_parent"
        android:layout_height="wrap_content"
        android:id="@+id/editText_surname"
        android:layout_alignTop="@+id/textView2"
        android:layout_toRightOf="@+id/textView2"
        android:layout_toEndOf="@+id/textView2" />
 
    <EditText
        android:layout_width="match_parent"
        android:layout_height="wrap_content"
        android:id="@+id/editText_Marks"
        android:layout_below="@+id/editText_surname"
        android:layout_toRightOf="@+id/textView3"
        android:layout_toEndOf="@+id/textView3" />
 
    <Button
        android:layout_width="wrap_content"
        android:layout_height="wrap_content"
        android:text="Add Data"
        android:id="@+id/button_add"
        android:layout_below="@+id/editText_Marks"
        android:layout_alignParentLeft="true"
        android:layout_alignParentStart="true"
        android:layout_marginTop="76dp" />
 
    <Button
        android:layout_width="wrap_content"
        android:layout_height="wrap_content"
        android:text="View All"
        android:id="@+id/button_viewAll"
        android:layout_above="@+id/button_update"
        android:layout_centerHorizontal="true" />
 
    <Button
        android:layout_width="wrap_content"
        android:layout_height="wrap_content"
        android:text="Update"
        android:id="@+id/button_update"
        android:layout_below="@+id/button_add"
        android:layout_alignParentLeft="true"
        android:layout_alignParentStart="true" />
 
 
    <Button
        android:layout_width="wrap_content"
        android:layout_height="wrap_content"
        android:text="Delete"
        android:id="@+id/button_delete"
        android:layout_centerVertical="true"
        android:layout_below="@+id/button_viewAll"
        android:layout_alignLeft="@+id/button_viewAll"
        android:layout_alignStart="@+id/button_viewAll" />
 
    <TextView
        android:layout_width="wrap_content"
        android:layout_height="wrap_content"
        android:textAppearance="?android:attr/textAppearanceLarge"
        android:text="id"
        android:id="@+id/textView_id"
        android:layout_below="@+id/editText_Marks"
        android:layout_alignParentLeft="true"
        android:layout_alignParentStart="true" />
 
    <EditText
        android:layout_width="match_parent"
        android:layout_height="wrap_content"
        android:id="@+id/editText_id"
        android:layout_alignTop="@+id/textView_id"
        android:layout_toRightOf="@+id/textView3"
        android:layout_toEndOf="@+id/textView3" />
 
</RelativeLayout>

Step 2 − Add the following code to res/layout/activity_main.xml.
Add the following code in this class to DatabaseHelper.java
package com.example.programmingknowledge.sqliteapp;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

/**
 * Created by ProgrammingKnowledge on 4/3/2015.
 */
public class DatabaseHelper extends SQLiteOpenHelper {
    public static final String DATABASE_NAME = "Student.db";
    public static final String TABLE_NAME = "student_table";
    public static final String COL_1 = "ID";
    public static final String COL_2 = "NAME";
    public static final String COL_3 = "SURNAME";
    public static final String COL_4 = "MARKS";

    public DatabaseHelper(Context context) {
        super(context, DATABASE_NAME, null, 1);
    }

    @Override
    public void onCreate(SQLiteDatabase db) {
        db.execSQL("create table " + TABLE_NAME +" (ID INTEGER PRIMARY KEY AUTOINCREMENT,NAME TEXT,SURNAME TEXT,MARKS INTEGER)");
    }

    @Override
    public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
        db.execSQL("DROP TABLE IF EXISTS "+TABLE_NAME);
        onCreate(db);
    }

    public boolean insertData(String name,String surname,String marks) {
        SQLiteDatabase db = this.getWritableDatabase();
        ContentValues contentValues = new ContentValues();
        contentValues.put(COL_2,name);
        contentValues.put(COL_3,surname);
        contentValues.put(COL_4,marks);
        long result = db.insert(TABLE_NAME,null ,contentValues);
        if(result == -1)
            return false;
        else
            return true;
    }

    public Cursor getAllData() {
        SQLiteDatabase db = this.getWritableDatabase();
        Cursor res = db.rawQuery("select * from "+TABLE_NAME,null);
        return res;
    }

    public boolean updateData(String id,String name,String surname,String marks) {
        SQLiteDatabase db = this.getWritableDatabase();
        ContentValues contentValues = new ContentValues();
        contentValues.put(COL_1,id);
        contentValues.put(COL_2,name);
        contentValues.put(COL_3,surname);
        contentValues.put(COL_4,marks);
        db.update(TABLE_NAME, contentValues, "ID = ?",new String[] { id });
        return true;
    }

    public Integer deleteData (String id) {
        SQLiteDatabase db = this.getWritableDatabase();
        return db.delete(TABLE_NAME, "ID = ?",new String[] {id});
    }
}
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
	
package com.example.programmingknowledge.sqliteapp;
 
import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
 
/**
 * Created by ProgrammingKnowledge on 4/3/2015.
 */
public class DatabaseHelper extends SQLiteOpenHelper {
    public static final String DATABASE_NAME = "Student.db";
    public static final String TABLE_NAME = "student_table";
    public static final String COL_1 = "ID";
    public static final String COL_2 = "NAME";
    public static final String COL_3 = "SURNAME";
    public static final String COL_4 = "MARKS";
 
    public DatabaseHelper(Context context) {
        super(context, DATABASE_NAME, null, 1);
    }
 
    @Override
    public void onCreate(SQLiteDatabase db) {
        db.execSQL("create table " + TABLE_NAME +" (ID INTEGER PRIMARY KEY AUTOINCREMENT,NAME TEXT,SURNAME TEXT,MARKS INTEGER)");
    }
 
    @Override
    public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
        db.execSQL("DROP TABLE IF EXISTS "+TABLE_NAME);
        onCreate(db);
    }
 
    public boolean insertData(String name,String surname,String marks) {
        SQLiteDatabase db = this.getWritableDatabase();
        ContentValues contentValues = new ContentValues();
        contentValues.put(COL_2,name);
        contentValues.put(COL_3,surname);
        contentValues.put(COL_4,marks);
        long result = db.insert(TABLE_NAME,null ,contentValues);
        if(result == -1)
            return false;
        else
            return true;
    }
 
    public Cursor getAllData() {
        SQLiteDatabase db = this.getWritableDatabase();
        Cursor res = db.rawQuery("select * from "+TABLE_NAME,null);
        return res;
    }
 
    public boolean updateData(String id,String name,String surname,String marks) {
        SQLiteDatabase db = this.getWritableDatabase();
        ContentValues contentValues = new ContentValues();
        contentValues.put(COL_1,id);
        contentValues.put(COL_2,name);
        contentValues.put(COL_3,surname);
        contentValues.put(COL_4,marks);
        db.update(TABLE_NAME, contentValues, "ID = ?",new String[] { id });
        return true;
    }
 
    public Integer deleteData (String id) {
        SQLiteDatabase db = this.getWritableDatabase();
        return db.delete(TABLE_NAME, "ID = ?",new String[] {id});
    }
}

MainActivity.java
package com.example.programmingknowledge.sqliteapp;

import android.app.AlertDialog;
import android.database.Cursor;
import android.support.v7.app.ActionBarActivity;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;


public class MainActivity extends ActionBarActivity {
    DatabaseHelper myDb;
    EditText editName,editSurname,editMarks ,editTextId;
    Button btnAddData;
    Button btnviewAll;
    Button btnDelete;

    Button btnviewUpdate;
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        myDb = new DatabaseHelper(this);

        editName = (EditText)findViewById(R.id.editText_name);
        editSurname = (EditText)findViewById(R.id.editText_surname);
        editMarks = (EditText)findViewById(R.id.editText_Marks);
        editTextId = (EditText)findViewById(R.id.editText_id);
        btnAddData = (Button)findViewById(R.id.button_add);
        btnviewAll = (Button)findViewById(R.id.button_viewAll);
        btnviewUpdate= (Button)findViewById(R.id.button_update);
        btnDelete= (Button)findViewById(R.id.button_delete);
        AddData();
        viewAll();
        UpdateData();
        DeleteData();
    }
    public void DeleteData() {
        btnDelete.setOnClickListener(
                new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {
                        Integer deletedRows = myDb.deleteData(editTextId.getText().toString());
                        if(deletedRows > 0)
                            Toast.makeText(MainActivity.this,"Data Deleted",Toast.LENGTH_LONG).show();
                        else
                            Toast.makeText(MainActivity.this,"Data not Deleted",Toast.LENGTH_LONG).show();
                    }
                }
        );
    }
    public void UpdateData() {
        btnviewUpdate.setOnClickListener(
                new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {
                        boolean isUpdate = myDb.updateData(editTextId.getText().toString(),
                                editName.getText().toString(),
                                editSurname.getText().toString(),editMarks.getText().toString());
                        if(isUpdate == true)
                            Toast.makeText(MainActivity.this,"Data Update",Toast.LENGTH_LONG).show();
                        else
                            Toast.makeText(MainActivity.this,"Data not Updated",Toast.LENGTH_LONG).show();
                    }
                }
        );
    }
    public  void AddData() {
        btnAddData.setOnClickListener(
                new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {
                       boolean isInserted = myDb.insertData(editName.getText().toString(),
                                editSurname.getText().toString(),
                                editMarks.getText().toString() );
                        if(isInserted == true)
                            Toast.makeText(MainActivity.this,"Data Inserted",Toast.LENGTH_LONG).show();
                        else
                            Toast.makeText(MainActivity.this,"Data not Inserted",Toast.LENGTH_LONG).show();
                    }
                }
        );
    }

    public void viewAll() {
        btnviewAll.setOnClickListener(
                new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {
                       Cursor res = myDb.getAllData();
                        if(res.getCount() == 0) {
                            // show message
                            showMessage("Error","Nothing found");
                            return;
                        }

                        StringBuffer buffer = new StringBuffer();
                        while (res.moveToNext()) {
                            buffer.append("Id :"+ res.getString(0)+"\n");
                            buffer.append("Name :"+ res.getString(1)+"\n");
                            buffer.append("Surname :"+ res.getString(2)+"\n");
                            buffer.append("Marks :"+ res.getString(3)+"\n\n");
                        }

                        // Show all data
                        showMessage("Data",buffer.toString());
                    }
                }
        );
    }

    public void showMessage(String title,String Message){
        AlertDialog.Builder builder = new AlertDialog.Builder(this);
        builder.setCancelable(true);
        builder.setTitle(title);
        builder.setMessage(Message);
        builder.show();
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }
}
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
	
package com.example.programmingknowledge.sqliteapp;
 
import android.app.AlertDialog;
import android.database.Cursor;
import android.support.v7.app.ActionBarActivity;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;
 
 
public class MainActivity extends ActionBarActivity {
    DatabaseHelper myDb;
    EditText editName,editSurname,editMarks ,editTextId;
    Button btnAddData;
    Button btnviewAll;
    Button btnDelete;
 
    Button btnviewUpdate;
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        myDb = new DatabaseHelper(this);
 
        editName = (EditText)findViewById(R.id.editText_name);
        editSurname = (EditText)findViewById(R.id.editText_surname);
        editMarks = (EditText)findViewById(R.id.editText_Marks);
        editTextId = (EditText)findViewById(R.id.editText_id);
        btnAddData = (Button)findViewById(R.id.button_add);
        btnviewAll = (Button)findViewById(R.id.button_viewAll);
        btnviewUpdate= (Button)findViewById(R.id.button_update);
        btnDelete= (Button)findViewById(R.id.button_delete);
        AddData();
        viewAll();
        UpdateData();
        DeleteData();
    }
    public void DeleteData() {
        btnDelete.setOnClickListener(
                new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {
                        Integer deletedRows = myDb.deleteData(editTextId.getText().toString());
                        if(deletedRows > 0)
                            Toast.makeText(MainActivity.this,"Data Deleted",Toast.LENGTH_LONG).show();
                        else
                            Toast.makeText(MainActivity.this,"Data not Deleted",Toast.LENGTH_LONG).show();
                    }
                }
        );
    }
    public void UpdateData() {
        btnviewUpdate.setOnClickListener(
                new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {
                        boolean isUpdate = myDb.updateData(editTextId.getText().toString(),
                                editName.getText().toString(),
                                editSurname.getText().toString(),editMarks.getText().toString());
                        if(isUpdate == true)
                            Toast.makeText(MainActivity.this,"Data Update",Toast.LENGTH_LONG).show();
                        else
                            Toast.makeText(MainActivity.this,"Data not Updated",Toast.LENGTH_LONG).show();
                    }
                }
        );
    }
    public  void AddData() {
        btnAddData.setOnClickListener(
                new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {
                       boolean isInserted = myDb.insertData(editName.getText().toString(),
                                editSurname.getText().toString(),
                                editMarks.getText().toString() );
                        if(isInserted == true)
                            Toast.makeText(MainActivity.this,"Data Inserted",Toast.LENGTH_LONG).show();
                        else
                            Toast.makeText(MainActivity.this,"Data not Inserted",Toast.LENGTH_LONG).show();
                    }
                }
        );
    }
 
    public void viewAll() {
        btnviewAll.setOnClickListener(
                new View.OnClickListener() {
                    @Override
                    public void onClick(View v) {
                       Cursor res = myDb.getAllData();
                        if(res.getCount() == 0) {
                            // show message
                            showMessage("Error","Nothing found");
                            return;
                        }
 
                        StringBuffer buffer = new StringBuffer();
                        while (res.moveToNext()) {
                            buffer.append("Id :"+ res.getString(0)+"\n");
                            buffer.append("Name :"+ res.getString(1)+"\n");
                            buffer.append("Surname :"+ res.getString(2)+"\n");
                            buffer.append("Marks :"+ res.getString(3)+"\n\n");
                        }
 
                        // Show all data
                        showMessage("Data",buffer.toString());
                    }
                }
        );
    }
 
    public void showMessage(String title,String Message){
        AlertDialog.Builder builder = new AlertDialog.Builder(this);
        builder.setCancelable(true);
        builder.setTitle(title);
        builder.setMessage(Message);
        builder.show();
    }
 
 
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }
 
    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();
 
        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }
 
        return super.onOptionsItemSelected(item);
    }
}
 
"""



Ans="""

<?xml version="1.0" encoding="utf-8"?>
<menu xmlns:android="http://schemas.android.com/apk/res/android"
    xmlns:app="http://schemas.android.com/apk/res-auto">
 
    <item
        android:id="@+id/item1"
        android:icon="@drawable/ic_icon"
        android:title="Item 1"
        app:showAsAction="ifRoom" />
 
    <item
        android:id="@+id/item2"
        android:title="Item 2"
        app:showAsAction="never" />
 
    <item
        android:id="@+id/item3"
        android:title="Item 3"
        app:showAsAction="never">
 
        <menu>
 
            <item
                android:id="@+id/subitem1"
                android:title="Sub Item 1" />
 
            <item
                android:id="@+id/subitem2"
                android:title="Sub Item 2" />
 
        </menu>
 
    </item>
 
</menu>

package com.example.application.optionsmenuexample;
 
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.widget.Toast;
 
public class MainActivity extends AppCompatActivity {
 
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
    }
 
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        MenuInflater inflater = getMenuInflater();
        inflater.inflate(R.menu.example_menu, menu);
        return true;
    }
 
    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
            case R.id.item1:
                Toast.makeText(this, "Item 1 selected", Toast.LENGTH_SHORT).show();
                return true;
            case R.id.item2:
                Toast.makeText(this, "Item 2 selected", Toast.LENGTH_SHORT).show();
                return true;
            case R.id.item3:
                Toast.makeText(this, "Item 3 selected", Toast.LENGTH_SHORT).show();
                return true;
            case R.id.subitem1:
                Toast.makeText(this, "Sub Item 1 selected", Toast.LENGTH_SHORT).show();
                return true;
            case R.id.subitem2:
                Toast.makeText(this, "Sub Item 2 selected", Toast.LENGTH_SHORT).show();
                return true;
            default:
                return super.onOptionsItemSelected(item);
        }
    }
}
    
"""



Ans="""

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Marksheet1
{
    class Program
    {
        static void Main(string[] args)
        {
            int r, m1, m2, m3, t;
            float p;
            string n;
            Console.WriteLine("Enter Roll Number :");
            r = Convert.ToInt32(Console.ReadLine());
            Console.WriteLine("Enter Student Name :");
            n = Console.ReadLine();
            Console.WriteLine("Mark of Subject1 : ");
            m1 = Convert.ToInt32(Console.ReadLine());
            Console.WriteLine("Mark of Subject2 : ");
            m2 = Convert.ToInt32(Console.ReadLine());
            Console.WriteLine("Mark of Subject3 : ");
            m3 = Convert.ToInt32(Console.ReadLine());
            t = m1 + m2 + m3;
            p = t / 3.0f;
            Console.WriteLine("Total : " + t);
            Console.WriteLine("Percentage : " + p);
            if (p >= 35 && p < 50)
            {
                Console.WriteLine("Grade is C");
            }
            if (p >= 50 && p <= 60)
            {
                Console.WriteLine("Grade is B");
            }
            if (p > 60 && p <= 80)
            {
                Console.WriteLine("Grade is A");
            }
            if (p > 80 && p <= 100)
            {
                Console.WriteLine("Grade is A+");
            }
            Console.ReadLine();
        }
    }
}

"""



Ans="""

using System;  
   public class Animal  
    {  
       public void eat() { Console.WriteLine("Eating..."); }  
   }  
   public class Dog: Animal  
   {  
       public void bark() { Console.WriteLine("Barking..."); }  
   }  
   public class BabyDog : Dog  
   {  
       public void weep() { Console.WriteLine("Weeping..."); }  
   }  
   class TestInheritance2{  
       public static void Main(string[] args)  
        {  
            BabyDog d1 = new BabyDog();  
            d1.eat();  
            d1.bark();  
            d1.weep();  
        }  
    } 

"""



Ans='''"""
    import heapq
    from collections import defaultdict
    def encode(frequency):
        heap = [[weight, [symbol, '']] for symbol, weight in frequency.items()]
        heapq.heapify(heap)
        while len(heap) > 1:
            low = heapq.heappop(heap)
            high = heapq.heappop(heap)
            for value in low[1:]:
                value[1] = '0' + value[1]
            for value in high[1:]:
                value[1] = '1' +value[1]
            heapq.heappush(heap, [low[0] + high[0]] + low[1:] + high[1:])
        return sorted(heapq.heappop(heap)[1:], key=lambda p: (len(p[-1]), p))
    string=input("Enter the string to be encoded:")
    frequency = defaultdict(int)
    for character in string:
        frequency[character] += 1
    huff = encode(frequency)
    print("character".ljust(10) + "Weight".ljust(10) + "Huffman Code")
    for i in huff:
        print(i[0].ljust(10) + str(frequency[i[0]]).ljust(10) + i[1])

"""
'''



Ans="""

packets not equal to port number
!(tcp.port==18)
analysis of tcp
tcp.analysis.flags
packets containing ipaddr 192.168.0.1 with a particular http request
http.request==192.168.0.1
Display packet containing content of tcp protocol
TCP->  Apply as columns of tcp protocol
To display http protocol with respcode200
http.response.code==200
reset tcp protocol
tcp.flags.reset==1

"""



Ans='''"""

BFS is one of the traversing algorithm used in graphs. This algorithm is implemented using a queue data structure. In this algorithm, the main focus is on the vertices of the graph. Select a starting node or vertex at first, mark the starting node or vertex as visited and store it in a queue. Then visit the vertices or nodes which are adjacent to the starting node, mark them as visited and store these vertices or nodes in a queue. Repeat this process until all the nodes or vertices are completely visited.

 

Advantages of BFS

    It can be useful in order to find whether the graph has connected components or not.
    It always finds or returns the shortest path if there is more than one path between two vertices.

 

Disadvantages of BFS

    The execution time of this algorithm is very slow because the time complexity of this algorithm is exponential.
    This algorithm is not useful when large graphs are used.

    graph = {'A': ['B', 'C', 'E'],
             'B': ['A','D', 'E'],
             'C': ['A', 'F', 'G'],
             'D': ['B'],
             'E': ['A', 'B','D'],
             'F': ['C'],
             'G': ['C']}
             
             
    def bfs(graph, initial):
        
        visited = []
        
        queue = [initial]
     
        while queue:
            
            node = queue.pop(0)
            if node not in visited:
                
                visited.append(node)
                neighbours = graph[node]
     
                
                for neighbour in neighbours:
                    queue.append(neighbour)
        return visited
     
    print(bfs(graph,'A'))

"""
'''



Ans='''"""
"""
def mergeSort(nlist):
    print("Splitting ",nlist)
    if len(nlist)>1:
        mid = len(nlist)//2
        lefthalf = nlist[:mid]
        righthalf = nlist[mid:]

        mergeSort(lefthalf)
        mergeSort(righthalf)
        i=j=k=0       
        while i < len(lefthalf) and j < len(righthalf):
            if lefthalf[i] < righthalf[j]:
                nlist[k]=lefthalf[i]
                i=i+1
            else:
                nlist[k]=righthalf[j]
                j=j+1
            k=k+1

        while i < len(lefthalf):
            nlist[k]=lefthalf[i]
            i=i+1
            k=k+1

        while j < len(righthalf):
            nlist[k]=righthalf[j]
            j=j+1
            k=k+1
    print("Merging ",nlist)

nlist = [14,46,43,27,57,41,45,21,70]
mergeSort(nlist)
print(nlist)
"""
'''



Ans="""
'''

Student.java
import java .io.Serializable;
public class Student
{
private String sname;
private int rno, marks;

public Student()
{
sname="";
}
public void setSname(String name)
{
sname = name;
}
public String getSname()
{
return sname;
}
public void setRno(int r)
{
rno = r;
}
public intgetRno()
{
return rno;
}
public void setMarks(int m)
{
marks = m;
}
public intgetMarks()
{
return marks;
}
} 

Hello.jsp

<%@page contentType="text/html" pageEncoding="UTF-8"%>
<!DOCTYPE html>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
<title> WELCOME TO STUDENT INFORMATION </title>
</head>
<jsp:useBean id="stud" class="Student" scope="reuest"/>
<jsp:setProperty name="stud" property="sname" value="Shreeji"/>
<jsp:setProperty name="stud" property="rno" value="52"/>
<jsp:setProperty name="stud" property="marks" value="95"/>
<body>
<h1>Name of Student is:<jsp:setProperty name="stud" property="sname"/></h1> 
<h1>Roll No of Student is:<jsp:setProperty name="stud" property="rno"/></h1>
<h1>Marks of Student is:<jsp:setProperty name="stud" property="marks"/></h1>
</body>
</html>


'''
"""



Ans="""

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Constructor_Overloading
{
    class GameScore
    {
        string user;
        int age;
        //Default Constructor
        public GameScore()
        {
            user = "Steven";
            age = 28;
            Console.WriteLine("Previous User {0} and he was {1} year old", user, age);
        }

        //Parameterized Constructor
        public GameScore(string name, int age1)
        {
            user = name;
            age = age1;
            Console.WriteLine("Current User {0} and he is {1} year old", user, age);
        }
    }

    class Program
    {
        static void Main(string[] args)
        {
            GameScore gs = new GameScore(); //Default Constructor Called
            GameScore gs1 = new GameScore("Clark", 35); //Overloaded Constructor.
            Console.ReadLine();
        }
    }
}
"""



Ans="""

Following is the content of the modified main activity file src/com.example.demo/MainActivity.java. This file can include each of the fundamental lifecycle methods.

package com.example.demo;

import android.os.Bundle;
import android.app.Activity;
import android.view.Menu;

public class MainActivity extends Activity {
   @Override
   protected void onCreate(Bundle savedInstanceState) {
      super.onCreate(savedInstanceState);
      setContentView(R.layout.activity_main);
   }
   
}

Following will be the content of res/layout/activity_main.xml file −

<TableLayout xmlns:android="http://schemas.android.com/apk/res/android"
   android:layout_width="fill_parent"
   android:layout_height="fill_parent">
   
   <TableRow
      android:layout_width="fill_parent"
      android:layout_height="fill_parent">
		
      <TextView
         android:text="Time"
         android:layout_width="wrap_content"
         android:layout_height="wrap_content"
         android:layout_column="1" />
			
      <TextClock
         android:layout_width="wrap_content"
         android:layout_height="wrap_content"
         android:id="@+id/textClock"
         android:layout_column="2" />
			
   </TableRow>
   
   <TableRow>
	
      <TextView
         android:text="First Name"
         android:layout_width="wrap_content"
         android:layout_height="wrap_content"
         android:layout_column="1" />
			
      <EditText
         android:width="200px"
         android:layout_width="wrap_content"
         android:layout_height="wrap_content" />
   </TableRow>
   
   <TableRow>
	
      <TextView
         android:text="Last Name"
         android:layout_width="wrap_content"
         android:layout_height="wrap_content"
         android:layout_column="1" />
			
      <EditText
         android:width="100px"
         android:layout_width="wrap_content"
         android:layout_height="wrap_content" />
   </TableRow>
   
   <TableRow
      android:layout_width="fill_parent"
      android:layout_height="fill_parent">
		
      <RatingBar
         android:layout_width="wrap_content"
         android:layout_height="wrap_content"
         android:id="@+id/ratingBar"
         android:layout_column="2" />
   </TableRow>
   
   <TableRow
      android:layout_width="fill_parent"
      android:layout_height="fill_parent"/>
		
   <TableRow
      android:layout_width="fill_parent"
      android:layout_height="fill_parent">
		
      <Button
         android:layout_width="wrap_content"
         android:layout_height="wrap_content"
         android:text="Submit"
         android:id="@+id/button"
         android:layout_column="2" />
   </TableRow>

</TableLayout>

Following will be the content of res/values/strings.xml to define two new constants −

<?xml version="1.0" encoding="utf-8"?>
<resources>
   <string name="app_name">HelloWorld</string>
   <string name="action_settings">Settings</string>
</resources>

"""



Ans="""

using System;
namespace Interest
{
 class Program
 {
 static void Main(string[] args)
 {
     int year;
     double princamt,rate, interest, total_amt;
     Console.Write("Enter The Loan Amount : ");
     princamt = Convert.ToDouble(Console.ReadLine());
     Console.Write("Enter The Number of Years : ");
     year = Convert.ToInt16(Console.ReadLine());
     Console.Write("Enter the Rate Of Interest : ");
     rate = Convert.ToDouble(Console.ReadLine());
     interest = princamt * year * rate / 100;
     total_amt = princamt + interest;
     Console.WriteLine("Total Amount : {0}", total_amt);
     Console.ReadLine();
 }
 }
}
        

"""



Ans="""

    using System;  
       namespace Animal  
        {
        class type{
        public void reptiles(){Console.WriteLine("snake")};
        public void birds(){Console.WriteLine("pigeon")};
        public void mammals(){Console.WriteLine("goat")};
        }
        }
    class program
    {
    static void main(String[] args)
    {
    animal type a=new animal.type();
    a.reptiles()
    a.birds()
    a.mammals()

    }

    }
        

"""



Ans="""
'''

import java.sql.*;
import java.io.*;
 
public class DatabaseImageExample {
	public static void main(String args[]){
		try{
			Class.forName("com.mysql.jdbc.Driver");
			Connection con=DriverManager.getConnection("jdbc:mysql://localhost/demo","root","root");
			
			File file=new File("E:\\image.png");
			FileInputStream fis=new FileInputStream(file);
			
			PreparedStatement ps=con.prepareStatement("insert into image_table (name,image) values(?,?)"); 
			ps.setString(1,"image 1");
			ps.setBinaryStream(2,fis,(int)file.length());
			ps.executeUpdate();
 
			ps.close();
			fis.close();
			con.close();
		}catch(Exception e){
			e.printStackTrace();
		}
	}
}

'''
"""



Ans="""
'''

import java.sql.*;
public class IssueBookDao {
	
public static boolean checkBook(String bookcallno){
	boolean status=false;
	try{
		Connection con=DB.getConnection();
		PreparedStatement ps=con.prepareStatement("select * from books where callno=?");
		ps.setString(1,bookcallno);
	    ResultSet rs=ps.executeQuery();
		status=rs.next();
		con.close();
	}catch(Exception e){System.out.println(e);}
	return status;
}

public static int save(String bookcallno,int studentid,String studentname,String studentcontact){
	int status=0;
	try{
		Connection con=DB.getConnection();
		
		status=updatebook(bookcallno);//updating quantity and issue
		
		if(status>0){
		PreparedStatement ps=con.prepareStatement("insert into issuebooks(bookcallno,studentid,studentname,studentcontact) values(?,?,?,?)");
		ps.setString(1,bookcallno);
		ps.setInt(2,studentid);
		ps.setString(3,studentname);
		ps.setString(4,studentcontact);
		status=ps.executeUpdate();
		}
		
		con.close();
	}catch(Exception e){System.out.println(e);}
	return status;
}
public static int updatebook(String bookcallno){
	int status=0;
	int quantity=0,issued=0;
	try{
		Connection con=DB.getConnection();
		
		PreparedStatement ps=con.prepareStatement("select quantity,issued from books where callno=?");
		ps.setString(1,bookcallno);
		ResultSet rs=ps.executeQuery();
		if(rs.next()){
			quantity=rs.getInt("quantity");
			issued=rs.getInt("issued");
		}
		
		if(quantity>0){
		PreparedStatement ps2=con.prepareStatement("update books set quantity=?,issued=? where callno=?");
		ps2.setInt(1,quantity-1);
		ps2.setInt(2,issued+1);
		ps2.setString(3,bookcallno);
		
		status=ps2.executeUpdate();
		}
		con.close();
	}catch(Exception e){System.out.println(e);}
	return status;
}
}

'''
"""



Ans="""

1. Twisted Pair Cable

A transmission medium consisting of pairs of twisted copper wires arranged in a regular spiral pattern to minimize the electromagnetic interference between adjacent pairs. Low frequency transmission medium only can transmit 1 Mbps over short distances. They are mainly used to transmit analog signals but they can be used for digital signals.
Twisted Pair Advantages
Inexpensive and readily available
Flexible and light weight
Easy to work with and install
Twisted Pair Disadvantages
Susceptibility to interference and noise Attenuation problem
For analog, repeaters needed every 5-6km
For digital, repeaters needed every 2-3km
Relatively low bandwidth (3000Hz)
Applications
They are used in telephone lines to provide voice and data channels.
Local area networks, such as 10 Base-T and 100 Base-T also use twisted-pair cables.
"""

"""
2. Coaxial Cable

Coaxial cable consists of a core made of solid copper surrounded by insulation a braided metal shielding and an outer cover.
A transmission medium consisting of thickly insulated copper wire which can transmit a large volume of data than twisted wire.
Coax Advantages
Higher bandwidth 400 to 600Mhz
up to 10,800 voice conversations
Much less susceptible to interference than twisted pair
Coax Disadvantages
High attenuation rate makes it expensive over long distance
Bulky
Applications
It is used in cable TV networks
It is used in traditional Ethernet LANs.

3. Fiber-optic Cable

New transmission medium used by telephone companies in place of long-distance trunk lines.
This cable also used by private companies in implementing local data communication networks.
Optical fiber consists of a glass cladding with slightly lower refractive index.
Fiber optic cable is used as the high speed backbone.
Fiber Optic Advantages Greater capacity (bandwidth of up to 2 Gbps).
Smaller size and lighter weight.
Lower attenuation.
immunity to environmental interference.
highly secure due to tap difficulty and lack of signal radiation.
Fiber Optic Disadvantages expensive over short distance
requires highly skilled installers adding additional nodes is difficult
Applications
The fiber optic cable is often found in backbone networks because its bandwidth is cost effective.
Used in TV companies.
LAN such as 100 Base-FX Network 

"""



Ans="""

13.3 FAST ETHERNET (100 MBPS)
In the 1990s, some LAN technologies with transmission rates higher than 10 Mbps,
such as FDDI and Fiber Channel, appeared on the market. If the Standard Ethernet
wanted to survive, it had to compete with these technologies. Ethernet made a big jump
by increasing the transmission rate to 100 Mbps, and the new generation was called the
Fast Ethernet. The designers of the Fast Ethernet needed to make it compatible with
the Standard Ethernet. The MAC sublayer was left unchanged, which meant the frame
format and the maximum and minimum size could also remain unchanged. By increasing
the transmission rate, features of the Standard Ethernet that depend on the transmission
rate, access method, and implementation had to be reconsidered. The goals of Fast Ether-
net can be summarized as follows:
1. Upgrade the data rate to 100 Mbps.
2. Make it compatible with Standard Ethernet.
3. Keep the same 48-bit address.
4. Keep the same frame format

"""



Ans="""

ip.addr(spcfc ip)
ip.src(spcfc src)
ip.dst(spcfc dst)
http.request(http request)
http.response.code=200(packets with no errors)
tcp.port==80||udp.port==80(packets on port 80)
tcp contains facebook(catch packets containing facebook)
http,tcp,icmp,udp,ftp(corres protocol)


"""



Ans="""
'''

import java.awt.BorderLayout;
import java.awt.EventQueue;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.border.EmptyBorder;
import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.JLabel;
import javax.swing.JOptionPane;

import java.awt.Font;
import java.awt.Color;
import javax.swing.JTextField;
import javax.swing.JPasswordField;
import javax.swing.LayoutStyle.ComponentPlacement;
import javax.swing.JButton;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

public class LibrarianForm extends JFrame {
	static LibrarianForm frame;
	private JPanel contentPane;
	private JTextField textField;
	private JTextField textField_1;
	private JTextField textField_2;
	private JTextField textField_3;
	private JTextField textField_4;
	private JPasswordField passwordField;

	/**
	 * Launch the application.
	 */
	public static void main(String[] args) {
		EventQueue.invokeLater(new Runnable() {
			public void run() {
				try {
					frame = new LibrarianForm();
					frame.setVisible(true);
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		});
	}

	/**
	 * Create the frame.
	 */
	public LibrarianForm() {
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		setBounds(100, 100, 450, 450);
		contentPane = new JPanel();
		contentPane.setBorder(new EmptyBorder(5, 5, 5, 5));
		setContentPane(contentPane);
		
		JLabel lblAddLibrarian = new JLabel("Add Librarian");
		lblAddLibrarian.setForeground(Color.DARK_GRAY);
		lblAddLibrarian.setFont(new Font("Tahoma", Font.PLAIN, 22));
		
		JLabel lblName = new JLabel("Name:");
		
		JLabel lblPassword = new JLabel("Password:");
		
		JLabel lblEmail = new JLabel("Email:");
		
		JLabel lblAddress = new JLabel("Address:");
		
		JLabel lblCity = new JLabel("City:");
		
		JLabel lblContactNo = new JLabel("Contact No:");
		
		textField = new JTextField();
		textField.setColumns(10);
		
		textField_1 = new JTextField();
		textField_1.setColumns(10);
		
		textField_2 = new JTextField();
		textField_2.setColumns(10);
		
		textField_3 = new JTextField();
		textField_3.setColumns(10);
		
		textField_4 = new JTextField();
		textField_4.setColumns(10);
		
		passwordField = new JPasswordField();
		
		JButton btnNewButton = new JButton("Add Librarian");
		btnNewButton.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
			String name=textField.getText();
			String password=String.valueOf(passwordField.getPassword());
			String email=textField_1.getText();
			String address=textField_2.getText();
			String city=textField_3.getText();
			String contact=textField_4.getText();

			int i=LibrarianDao.save(name, password, email, address, city, contact);
			if(i>0){
				JOptionPane.showMessageDialog(LibrarianForm.this,"Librarian added successfully!");
				AdminSuccess.main(new String[]{});
				frame.dispose();
				
			}else{
				JOptionPane.showMessageDialog(LibrarianForm.this,"Sorry, unable to save!");
			}
			}
		});
		btnNewButton.setForeground(Color.DARK_GRAY);
		
		JButton btnBack = new JButton("Back");
		btnBack.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
			AdminSuccess.main(new String[]{});
			frame.dispose();
			}
		});
		GroupLayout gl_contentPane = new GroupLayout(contentPane);
		gl_contentPane.setHorizontalGroup(
			gl_contentPane.createParallelGroup(Alignment.TRAILING)
				.addGroup(gl_contentPane.createSequentialGroup()
					.addGap(20)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.LEADING, false)
						.addComponent(lblPassword, GroupLayout.DEFAULT_SIZE, 62, Short.MAX_VALUE)
						.addComponent(lblName)
						.addComponent(lblEmail, GroupLayout.PREFERRED_SIZE, 31, GroupLayout.PREFERRED_SIZE)
						.addComponent(lblAddress, GroupLayout.DEFAULT_SIZE, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE)
						.addComponent(lblCity, GroupLayout.PREFERRED_SIZE, 31, GroupLayout.PREFERRED_SIZE)
						.addComponent(lblContactNo, GroupLayout.DEFAULT_SIZE, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
					.addGap(58)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.LEADING, false)
						.addComponent(textField_4, GroupLayout.DEFAULT_SIZE, 177, Short.MAX_VALUE)
						.addComponent(textField_3, GroupLayout.DEFAULT_SIZE, 177, Short.MAX_VALUE)
						.addComponent(textField_2, GroupLayout.DEFAULT_SIZE, 177, Short.MAX_VALUE)
						.addComponent(textField_1, GroupLayout.DEFAULT_SIZE, 177, Short.MAX_VALUE)
						.addComponent(textField, GroupLayout.DEFAULT_SIZE, 177, Short.MAX_VALUE)
						.addComponent(passwordField))
					.addContainerGap(107, Short.MAX_VALUE))
				.addGroup(gl_contentPane.createSequentialGroup()
					.addContainerGap(151, Short.MAX_VALUE)
					.addComponent(lblAddLibrarian)
					.addGap(144))
				.addGroup(gl_contentPane.createSequentialGroup()
					.addContainerGap(160, Short.MAX_VALUE)
					.addComponent(btnNewButton, GroupLayout.PREFERRED_SIZE, 131, GroupLayout.PREFERRED_SIZE)
					.addGap(133))
				.addGroup(gl_contentPane.createSequentialGroup()
					.addContainerGap(200, Short.MAX_VALUE)
					.addComponent(btnBack)
					.addGap(169))
		);
		gl_contentPane.setVerticalGroup(
			gl_contentPane.createParallelGroup(Alignment.LEADING)
				.addGroup(gl_contentPane.createSequentialGroup()
					.addComponent(lblAddLibrarian)
					.addGap(18)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.LEADING)
						.addGroup(gl_contentPane.createSequentialGroup()
							.addComponent(lblName)
							.addGap(18)
							.addComponent(lblPassword))
						.addGroup(gl_contentPane.createSequentialGroup()
							.addComponent(textField, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE)
							.addPreferredGap(ComponentPlacement.UNRELATED)
							.addComponent(passwordField, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE)))
					.addGap(18)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.BASELINE)
						.addComponent(lblEmail)
						.addComponent(textField_1, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
					.addGap(18)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.BASELINE)
						.addComponent(lblAddress)
						.addComponent(textField_2, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
					.addGap(18)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.BASELINE)
						.addComponent(lblCity)
						.addComponent(textField_3, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
					.addGap(18)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.BASELINE)
						.addComponent(lblContactNo)
						.addComponent(textField_4, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
					.addGap(18)
					.addComponent(btnNewButton, GroupLayout.PREFERRED_SIZE, 36, GroupLayout.PREFERRED_SIZE)
					.addPreferredGap(ComponentPlacement.RELATED, 57, Short.MAX_VALUE)
					.addComponent(btnBack)
					.addGap(19))
		);
		contentPane.setLayout(gl_contentPane);
	}

}
'''
"""



Ans="""

Star:- 4PCS in plus sign, 1 hub in between
Mesh:- 4 Switches connected to each other, each connected to 1 pc
Bus:- One Server connected to one switch with pc attached. The switch connected to 2 identical PC wala switches
Ring:- Benzene ring of switches with one pc each
Hub Connected to 5 PCs
Switch Connected to 6 PCs


"""



Ans="""


    int numberoflayer = 6, Space, Number;  
    Console.WriteLine("Print paramid");  
    for (int i = 1; i <= numberoflayer; i++) // Total number of layer for pramid  
    {  
        for (Space = 1; Space <= (numberoflayer - i); Space++) // Loop For Space  
            Console.Write(" ");  
        for (Number = 1; Number <= i; Number++) //increase the value  
            Console.Write('*');  
        for (Number = (i - 1); Number >= 1; Number--) //decrease the value  
            Console.Write('*');  
        Console.WriteLine();  
    } 

"""



Ans="""

'''
We are given a matrix, we need to check whether it is an orthogonal matrix or not. An orthogonal matrix is a square matrix and satisfies the following condition:

  A*At = I
'''

def isOrthogonal(a, m, n) : 
    if (m != n) : 
        return False
      
    # Multiply A*A^t 
    for i in range(0, n) : 
        for j in range(0, n) :  
            sum = 0
            for k in range(0, n) : 
          
                # Since we are multiplying  
                # with transpose of itself. 
                # We use a[j][k] instead 
                # of a[k][j] 
                sum = sum + (a[i][k] *
                             a[j][k]) 
          
        if (i == j and sum != 1) : 
            return False
        if (i != j and sum != 0) : 
            return False
  
    return True
  
# Driver Code 
a = [[1, 0, 0], 
     [0, 1, 0], 
     [0, 0, 1]] 
if (isOrthogonal(a, 3, 3)) : 
    print ("Yes") 
else : 
    print ("No") 
"""



Ans="""

AIM    :    Capturing    and    analyzing    network    packets    using    Wireshark        (Fundamentals)
:- Identification the live network - Capture Packets- Analyze the captured packets
Capturing Packets
Capture traffic on your wireless network, click your wireless interface.
You can configure advanced features by clicking Capture > Options, but this isn’t necessary for now.

As soon as you single-click on your network interface’s name, you can see how the packets are working in real time.
Wireshark will capture all the packets going in and out of our systems.
Promiscuous mode is the mode in which you can see all the packets from other systems  on  the  network
and  not  only  the  packets  send  or  received  from  your  network adapter. Promiscuous mode is enabled by default.
To check if this mode is  enabled,  go  to  Capture  and  Select  Options.  Under  this  window  check,  if  the
checkbox is selected and activated at the bottom of the window. The checkbox says “Enable promiscuous mode on all interfaces”
The red box button “STOP” on the top left side of the window can be clicked to stop the capturing of traffic on the network.
Color CodingDifferent  packets  are  seen  highlighted in  various  different  colors.
This  is  Wireshark’s way of displaying traffic to help you easily identify the types of it.
Default colors are:Light Purple color for TCP traffic
Light Blue color for UDP traffic Black color identifies packets with errors
– example these packets are delivered in an unordered manner.
To check the color coding rules click on View and select Coloring Rules.
These color coding rules can be customized and modified to fit your needs

Analyze the captured Packets:First of all, click on a packet and select it.
Now, you can scroll down to view all its details

Filters can also be created from here. Right-click on one of any details.
From the menu select Apply as Filter drop-down menu so filter based on it can be created

"""



Ans="""

<?xml version="1.0" encoding="utf-8"?> 
<RelativeLayout xmlns:android="http://schemas.android.com/apk/res/android"
    xmlns:app="http://schemas.android.com/apk/res-auto"
    xmlns:tools="http://schemas.android.com/tools"
    android:layout_width="match_parent"
    android:layout_height="match_parent"
    tools:context=".MainActivity"
    tools:layout_editor_absoluteY="81dp"> 
  
    <!-- Text view for result view-->
    <TextView
        android:id="@+id/textView_answer"
        android:layout_width="100dp"
        android:layout_height="25dp"
        android:layout_marginLeft="130dp"
        android:layout_marginTop="300dp"
        android:text="0"
        android:textSize="20dp"
        android:textStyle="bold" /> 
  
    <!--take the input first number-->
    <EditText
        android:id="@+id/editText_first_no"
        android:layout_width="150dp"
        android:layout_height="40dp"
        android:layout_marginLeft="200dp"
        android:layout_marginTop="40dp"
        android:inputType="number" /> 
    <!-- for messege input first number-->
    <TextView
        android:id="@+id/textView_first_no"
        android:layout_width="150dp"
        android:layout_height="25dp"
        android:layout_marginLeft="10dp"
        android:layout_marginTop="50dp"
        android:text="First number"
        android:textSize="20dp" /> 
  
    <!--view messege -->
    <TextView
        android:id="@+id/textView_second_no"
        android:layout_width="150dp"
        android:layout_height="25dp"
        android:layout_marginLeft="10dp"
        android:layout_marginTop="100dp"
        android:text="Second number"
        android:textSize="20dp" /> 
  
    <!-- take input for second number -->
  
    <EditText
        android:id="@+id/editText_second_no"
        android:layout_width="150dp"
        android:layout_height="40dp"
        android:layout_marginLeft="200dp"
        android:layout_marginTop="90dp"
        android:inputType="number"
        tools:ignore="MissingConstraints" /> 
  
    <!-- button for run add logic and view result -->
  
    <Button
        android:id="@+id/add_button"
        android:layout_width="100dp"
        android:layout_height="50dp"
        android:layout_marginLeft="110dp"
        android:layout_marginTop="200dp"
        android:text="ADD" /> 
  
</RelativeLayout> 

package org.geeksforgeeks.addtwonumbers; 
  
import android.support.v7.app.AppCompatActivity; 
import android.os.Bundle; 
import android.view.View; 
import android.widget.Button; 
import android.widget.EditText; 
import android.widget.TextView; 
  
public class MainActivity extends AppCompatActivity { 
  
    // define the global variable 
  
    // variable number1, number2 for input input number 
    // Add_button, result textView 
  
    EditText number1; 
    EditText number2; 
    Button Add_button; 
    TextView result; 
    int ans=0; 
  
    @Override
    protected void onCreate(Bundle savedInstanceState) { 
        super.onCreate(savedInstanceState); 
        setContentView(R.layout.activity_main); 
  
        // by ID we can use each component which id is assign in xml file 
        number1=(EditText) findViewById(R.id.editText_first_no); 
        number2=(EditText) findViewById(R.id.editText_second_no); 
        Add_button=(Button) findViewById(R.id.add_button); 
        result = (TextView) findViewById(R.id.textView_answer); 
  
        // Add_button add clicklistener 
        Add_button.setOnClickListener(new View.OnClickListener() { 
  
            public void onClick(View v) { 
  
                // num1 or num2 double type 
                // get data which is in edittext, convert it to string 
                // using parse Double convert it to Double type 
                double num1 = Double.parseDouble(number1.getText().toString()); 
                double num2 = Double.parseDouble(number2.getText().toString()); 
                // add both number and store it to sum 
                double sum = num1 + num2; 
                // set it ot result textview 
                result.setText(Double.toString(sum)); 
            } 
        }); 
    } 
} 
"""



Ans="""
'''
Nullity can be defined as the number of vectors present in the null space
of a given matrix. In other words, the dimension of the null space of the
matrix A is called the nullity of A. The number of linear relations among
the attributes is given by the size of the null space.
The null space vectors B can be used to identify these linear relationship.
'''

from sympy import Matrix 
  
A = [[1, 2, 0], [2, 4, 0], [3, 6, 1]] 
   
A = Matrix(A) 
  
# Number of Columns 
NoC = A.shape[1] 
  
# Rank of A 
rank = A.rank() 
  
# Nullity of the Matrix 
nullity = NoC - rank 
  
print("Nullity : ", nullity) 

"""



Ans="""
'''

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;

public class ReturnBookDao {
	public static int delete(String bookcallno,int studentid){
		int status=0;
		try{
			Connection con=DB.getConnection();
			
			status=updatebook(bookcallno);//updating quantity and issue
			
			if(status>0){
			PreparedStatement ps=con.prepareStatement("delete from issuebooks where bookcallno=? and studentid=?");
			ps.setString(1,bookcallno);
			ps.setInt(2,studentid);
			status=ps.executeUpdate();
			}
			
			con.close();
		}catch(Exception e){System.out.println(e);}
		return status;
	}
	public static int updatebook(String bookcallno){
		int status=0;
		int quantity=0,issued=0;
		try{
			Connection con=DB.getConnection();
			
			PreparedStatement ps=con.prepareStatement("select quantity,issued from books where callno=?");
			ps.setString(1,bookcallno);
			ResultSet rs=ps.executeQuery();
			if(rs.next()){
				quantity=rs.getInt("quantity");
				issued=rs.getInt("issued");
			}
			
			if(issued>0){
			PreparedStatement ps2=con.prepareStatement("update books set quantity=?,issued=? where callno=?");
			ps2.setInt(1,quantity+1);
			ps2.setInt(2,issued-1);
			ps2.setString(3,bookcallno);
			
			status=ps2.executeUpdate();
			}
			con.close();
		}catch(Exception e){System.out.println(e);}
		return status;
	}
}
'''
"""



Ans="""

File: activity_main.xml

    <RelativeLayout xmlns:androclass="http://schemas.android.com/apk/res/android"  
        xmlns:tools="http://schemas.android.com/tools"  
        android:layout_width="match_parent"  
        android:layout_height="match_parent"  
        tools:context=".MainActivity" >  
      
        <Button  
            android:id="@+id/button1"  
            android:layout_width="wrap_content"  
            android:layout_height="wrap_content"  
            android:layout_alignParentTop="true"  
            android:layout_centerHorizontal="true"  
            android:layout_marginTop="116dp"  
            android:text="download file" />  
      
    </RelativeLayout>  

Activity class

Let's write the code to display the progress bar dialog box.
File: MainActivity.java

    package example.javatpoint.com.progressbar;  
      
    import android.app.ProgressDialog;  
    import android.os.Handler;  
    import android.support.v7.app.AppCompatActivity;  
    import android.os.Bundle;  
    import android.view.View;  
    import android.widget.Button;  
      
    public class MainActivity extends AppCompatActivity {  
        Button btnStartProgress;  
        ProgressDialog progressBar;  
        private int progressBarStatus = 0;  
        private Handler progressBarHandler = new Handler();  
        private long fileSize = 0;  
        @Override  
        protected void onCreate(Bundle savedInstanceState) {  
            super.onCreate(savedInstanceState);  
            setContentView(R.layout.activity_main);  
            addListenerOnButtonClick();  
        }  
        public void addListenerOnButtonClick() {  
            btnStartProgress = findViewById(R.id.button);  
            btnStartProgress.setOnClickListener(new View.OnClickListener(){  
      
                @Override  
                public void onClick(View v) {  
                    // creating progress bar dialog  
                    progressBar = new ProgressDialog(v.getContext());  
                    progressBar.setCancelable(true);  
                    progressBar.setMessage("File downloading ...");  
                    progressBar.setProgressStyle(ProgressDialog.STYLE_HORIZONTAL);  
                    progressBar.setProgress(0);  
                    progressBar.setMax(100);  
                    progressBar.show();  
                    //reset progress bar and filesize status  
                    progressBarStatus = 0;  
                    fileSize = 0;  
      
                    new Thread(new Runnable() {  
                        public void run() {  
                            while (progressBarStatus < 100) {  
                                // performing operation  
                                progressBarStatus = doOperation();  
                                try {  
                                    Thread.sleep(1000);  
                                } catch (InterruptedException e) {  
                                    e.printStackTrace();  
                                }  
                                // Updating the progress bar  
                                progressBarHandler.post(new Runnable() {  
                                    public void run() {  
                                        progressBar.setProgress(progressBarStatus);  
                                    }  
                                });  
                            }  
                            // performing operation if file is downloaded,  
                            if (progressBarStatus >= 100) {  
                                // sleeping for 1 second after operation completed  
                                try {  
                                    Thread.sleep(1000);  
                                } catch (InterruptedException e) {  
                                    e.printStackTrace();  
                                }  
                                // close the progress bar dialog  
                                progressBar.dismiss();  
                            }  
                        }  
                    }).start();  
                }//end of onClick method  
            });  
        }  
        // checking how much file is downloaded and updating the filesize  
        public int doOperation() {  
            //The range of ProgressDialog starts from 0 to 10000  
            while (fileSize <= 10000) {  
                fileSize++;  
                if (fileSize == 1000) {  
                    return 10;  
                } else if (fileSize == 2000) {  
                    return 20;  
                } else if (fileSize == 3000) {  
                    return 30;  
                } else if (fileSize == 4000) {  
                    return 40; // you can add more else if   
                }   
             /* else { 
                    return 100; 
                }*/  
            }//end of while  
                return 100;  
        }//end of doOperation  
    }  
    
"""



Ans="""

13.2 STANDARD ETHERNET
We refer to the original Ethernet technology with the data rate of 10 Mbps as the Stan-
dard Ethernet. Although most implementations have moved to other technologies in
the Ethernet evolution, there are some features of the Standard Ethernet that have not
changed during the evolution. We discuss this standard version to pave the way for
understanding the other three technologies. 
13.2.1 Characteristics
Let us first discuss some characteristics of the Standard Ethernet.
Connectionless and Unreliable Service
Ethernet provides a connectionless service, which means each frame sent is independent
of the previous or next frame. Ethernet has no connection establishment or connection
termination phases. The sender sends a frame whenever it has it; the receiver may or may
not be ready for it. The sender may overwhelm the receiver with frames, which may result
in dropping frames. If a frame drops, the sender will not know about it. Since IP, which is
using the service of Ethernet, is also connectionless, it will not know about it either. If the
transport layer is also a connectionless protocol, such as UDP, the frame is lost and
salvation may only come from the application layer. However, if the transport layer is
TCP, the sender TCP does not receive acknowledgment for its segment and sends it again. 
Ethernet is also unreliable like IP and UDP. If a frame is corrupted during trans-
mission and the receiver finds out about the corruption, which has a high level of prob-
ability of happening because of the CRC-32, the receiver drops the frame silently. It is
the duty of high-level protocols to find out about it.

"""



Ans="""
'''

import java.sql.*;
public class LibrarianDao {

	
	public static int save(String name,String password,String email,String address,String city,String contact){
		int status=0;
		try{
			Connection con=DB.getConnection();
			PreparedStatement ps=con.prepareStatement("insert into librarian(name,password,email,address,city,contact) values(?,?,?,?,?,?)");
			ps.setString(1,name);
			ps.setString(2,password);
			ps.setString(3,email);
			ps.setString(4,address);
			ps.setString(5,city);
			ps.setString(6,contact);
			status=ps.executeUpdate();
			con.close();
		}catch(Exception e){System.out.println(e);}
		return status;
	}
	public static int delete(int id){
		int status=0;
		try{
			Connection con=DB.getConnection();
			PreparedStatement ps=con.prepareStatement("delete from librarian where id=?");
			ps.setInt(1,id);
			status=ps.executeUpdate();
			con.close();
		}catch(Exception e){System.out.println(e);}
		return status;
	}

	public static boolean validate(String name,String password){
		boolean status=false;
		try{
			Connection con=DB.getConnection();
			PreparedStatement ps=con.prepareStatement("select * from librarian where name=? and password=?");
			ps.setString(1,name);
			ps.setString(2,password);
			ResultSet rs=ps.executeQuery();
			status=rs.next();
			con.close();
		}catch(Exception e){System.out.println(e);}
		return status;
	}

}
'''
"""



Ans='''"""

This algorithm is a recursive algorithm which follows the concept of backtracking and implemented using stack data structure. But, what is backtracking.

Backtracking:-

It means whenever a tree or a graph is moving forward and there are no nodes along the existing path, the tree moves backwards along the same path which it went forward in order to find new nodes to traverse. This process keeps on iterating until all the unvisited nodes are visited.

How stack is implemented in DFS:-

    Select a starting node, mark the starting node as visited and push it into the stack.
    Explore any one of adjacent nodes of the starting node which are unvisited.
    Mark the unvisited node as visited and push it into the stack.
    Repeat this process until all the nodes in the tree or graph are visited.
    Once all the nodes are visited, then pop all the elements in the stack until the stack becomes empty.

    import sys
    def ret_graph():
        return {
            'A': {'B':5.5, 'C':2, 'D':6},
            'B': {'A':5.5, 'E':3},
            'C': {'A':2, 'F':2.5},
            'D': {'A':6, 'F':1.5},
            'E': {'B':3, 'J':7},
            'F': {'C':2.5, 'D':1.5, 'K':1.5, 'G':3.5},
            'G': {'F':3.5, 'I':4},
            'H': {'J':2},
            'I': {'G':4, 'J':4},
            'J': {'H':2, 'I':4},
            'K': {'F':1.5}
        }
    start = 'A'                 
    dest = 'J'                  
    visited = []                
    stack = []                  
    graph = ret_graph()
    path = []
    stack.append(start)                  
    visited.append(start)                
    while stack:                         
        curr = stack.pop()            
        path.append(curr)
        for neigh in graph[curr]:        
            if neigh not in visited:       
                visited.append(neigh)       
                stack.append(neigh)         
                if neigh == dest :            
                    print("FOUND:", neigh)
                    print(path)
                    sys.exit(0)
    print("Not found")
    print(path)

"""
'''



Ans="""



    SqlConnection nwindConn = new SqlConnection("Data Source=localhost;Integrated Security=SSPI;Initial Catalog=northwind");  
    SqlCommand selectCMD = new SqlCommand("SELECT CustomerID, CompanyName FROM Customers", nwindConn);  
    selectCMD.CommandTimeout = 30;  
    SqlDataAdapter customerDA = new SqlDataAdapter();  
    customerDA.SelectCommand = selectCMD;  
    nwindConn.Open();  
    DataSet customerDS = new DataSet();  
    customerDA.Fill(customerDS, "Customers");  
    nwindConn.Close();  


        

"""



Ans="""

import numpy as np
u=np.array((3,4,5))
v=np.array((1,2,7))
print("vector u",u)
print("vector v",v)
print("enter the value of a and b")
a=float(input())
b=float(input())
d=(a*u)+(b*v)
p=np.dot(u,v)
print("vector au+bv",d)
print("dot product of u and v:",p)


"""



Ans="""

string myName = "myName is Shreesh";  
       myName = myName.ToUpper();  
       Console.WriteLine(myName);

myName = myName.ToLower();  
Console.WriteLine(myName);

       myName = myName.Trim();  
Console.WriteLine(myName);

       bool  isContains = myName.Contains("SHREESH");  
       Console.WriteLine(isContains);

char[] charArray = myName.ToCharArray();  
foreach(char c in charArray)  
      {  
    Console.WriteLine(c);  
}

string myName = "myName is SHREESH";  
         myName =  myName.Substring(0, 6);  
    Console.WriteLine(myName);

"""



Ans="""
'''

import java.awt.BorderLayout;
import java.awt.EventQueue;

import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.border.EmptyBorder;
import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.JLabel;
import javax.swing.JOptionPane;

import java.awt.Font;
import java.awt.Color;
import javax.swing.JTextField;
import javax.swing.JButton;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import javax.swing.LayoutStyle.ComponentPlacement;

public class BooksForm extends JFrame {
	static BooksForm frame;
	private JPanel contentPane;
	private JTextField textField;
	private JTextField textField_1;
	private JTextField textField_2;
	private JTextField textField_3;
	private JTextField textField_4;

	/**
	 * Launch the application.
	 */
	public static void main(String[] args) {
		EventQueue.invokeLater(new Runnable() {
			public void run() {
				try {
					frame = new BooksForm();
					frame.setVisible(true);
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		});
	}

	/**
	 * Create the frame.
	 */
	public BooksForm() {
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		setBounds(100, 100, 450, 404);
		contentPane = new JPanel();
		contentPane.setBorder(new EmptyBorder(5, 5, 5, 5));
		setContentPane(contentPane);
		
		JLabel lblAddBooks = new JLabel("Add Books");
		lblAddBooks.setForeground(Color.GRAY);
		lblAddBooks.setFont(new Font("Tahoma", Font.PLAIN, 18));
		
		JLabel lblCallNo = new JLabel("Call No:");
		
		JLabel lblName = new JLabel("Name:");
		
		JLabel lblAuthor = new JLabel("Author:");
		
		JLabel lblPublisher = new JLabel("Publisher:");
		
		JLabel lblQuantity = new JLabel("Quantity:");
		
		textField = new JTextField();
		textField.setColumns(10);
		
		textField_1 = new JTextField();
		textField_1.setColumns(10);
		
		textField_2 = new JTextField();
		textField_2.setColumns(10);
		
		textField_3 = new JTextField();
		textField_3.setColumns(10);
		
		textField_4 = new JTextField();
		textField_4.setColumns(10);
		
		JButton btnAddBooks = new JButton("Add Books");
		btnAddBooks.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
			String callno=textField.getText();
			String name=textField_1.getText();
			String author=textField_2.getText();
			String publisher=textField_3.getText();
			String squantity=textField_4.getText();
			int quantity=Integer.parseInt(squantity);
			int i=BookDao.save(callno, name, author, publisher, quantity);
			if(i>0){
				JOptionPane.showMessageDialog(BooksForm.this,"Books added successfully!");
				LibrarianSuccess.main(new String[]{});
				frame.dispose();
				
			}else{
				JOptionPane.showMessageDialog(BooksForm.this,"Sorry, unable to save!");
			}
			}
		});
		
		JButton btnBack = new JButton("Back");
		GroupLayout gl_contentPane = new GroupLayout(contentPane);
		gl_contentPane.setHorizontalGroup(
			gl_contentPane.createParallelGroup(Alignment.TRAILING)
				.addGroup(gl_contentPane.createSequentialGroup()
					.addGroup(gl_contentPane.createParallelGroup(Alignment.LEADING)
						.addGroup(gl_contentPane.createSequentialGroup()
							.addGap(150)
							.addComponent(lblAddBooks))
						.addGroup(gl_contentPane.createSequentialGroup()
							.addGap(18)
							.addGroup(gl_contentPane.createParallelGroup(Alignment.LEADING, false)
								.addComponent(lblName, GroupLayout.PREFERRED_SIZE, 37, GroupLayout.PREFERRED_SIZE)
								.addComponent(lblCallNo)
								.addComponent(lblAuthor, GroupLayout.PREFERRED_SIZE, 37, GroupLayout.PREFERRED_SIZE)
								.addComponent(lblPublisher, GroupLayout.DEFAULT_SIZE, 67, Short.MAX_VALUE)
								.addComponent(lblQuantity, GroupLayout.PREFERRED_SIZE, 55, GroupLayout.PREFERRED_SIZE))
							.addGap(47)
							.addGroup(gl_contentPane.createParallelGroup(Alignment.LEADING)
								.addComponent(textField_4, GroupLayout.PREFERRED_SIZE, 167, GroupLayout.PREFERRED_SIZE)
								.addComponent(textField_3, GroupLayout.PREFERRED_SIZE, 167, GroupLayout.PREFERRED_SIZE)
								.addComponent(textField_2, GroupLayout.PREFERRED_SIZE, 167, GroupLayout.PREFERRED_SIZE)
								.addComponent(textField_1, GroupLayout.PREFERRED_SIZE, 167, GroupLayout.PREFERRED_SIZE)
								.addComponent(textField, GroupLayout.PREFERRED_SIZE, 167, GroupLayout.PREFERRED_SIZE))))
					.addContainerGap(125, Short.MAX_VALUE))
				.addGroup(Alignment.LEADING, gl_contentPane.createSequentialGroup()
					.addGap(161)
					.addComponent(btnAddBooks, GroupLayout.PREFERRED_SIZE, 101, GroupLayout.PREFERRED_SIZE)
					.addContainerGap(162, Short.MAX_VALUE))
				.addGroup(gl_contentPane.createSequentialGroup()
					.addContainerGap(359, Short.MAX_VALUE)
					.addComponent(btnBack)
					.addContainerGap())
		);
		gl_contentPane.setVerticalGroup(
			gl_contentPane.createParallelGroup(Alignment.LEADING)
				.addGroup(gl_contentPane.createSequentialGroup()
					.addComponent(lblAddBooks)
					.addGap(18)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.BASELINE)
						.addComponent(lblCallNo)
						.addComponent(textField, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
					.addGap(18)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.BASELINE)
						.addComponent(lblName)
						.addComponent(textField_1, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
					.addGap(18)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.BASELINE)
						.addComponent(lblAuthor)
						.addComponent(textField_2, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
					.addGap(18)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.BASELINE)
						.addComponent(lblPublisher)
						.addComponent(textField_3, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
					.addGap(18)
					.addGroup(gl_contentPane.createParallelGroup(Alignment.BASELINE)
						.addComponent(lblQuantity)
						.addComponent(textField_4, GroupLayout.PREFERRED_SIZE, GroupLayout.DEFAULT_SIZE, GroupLayout.PREFERRED_SIZE))
					.addGap(30)
					.addComponent(btnAddBooks, GroupLayout.PREFERRED_SIZE, 31, GroupLayout.PREFERRED_SIZE)
					.addPreferredGap(ComponentPlacement.RELATED)
					.addComponent(btnBack)
					.addContainerGap(53, Short.MAX_VALUE))
		);
		contentPane.setLayout(gl_contentPane);
	}

}
'''
"""
